/*
 * Dashforge Page Components
 *
 * This style is use for demo purpose only.
 *
 */
.content-components {
  font-size: 16px;
  padding: 20px;
  position: relative;
  color: #1b2e4b;
  letter-spacing: -0.2px; }
  @media (min-width: 992px) {
    .content-components {
      padding: 25px;
      margin-top: 60px;
      margin-left: 240px; } }
  @media (min-width: 1200px) {
    .content-components {
      padding: 30px;
      margin-right: 240px; } }
  .content-components .container {
    padding: 0;
    max-width: 780px; }
  .content-components pre[class*="language-"],
  .content-components code[class*="language-"] {
    border-color: rgba(72, 94, 144, 0.16);
    font-family: 'Roboto Mono', monospace;
    font-size: 12px;
    letter-spacing: normal;
    background-color: #f8f9fc; }

.df-breadcrumbs {
  padding: 0;
  background-color: transparent; }
  .df-breadcrumbs .breadcrumb-item {
    font-size: 10px;
    text-transform: uppercase;
    font-weight: 600;
    font-family: -apple-system, BlinkMacSystemFont, "Inter UI", Roboto, sans-serif; }
    @media (min-width: 576px) {
      .df-breadcrumbs .breadcrumb-item {
        letter-spacing: .5px; } }
    .df-breadcrumbs .breadcrumb-item a {
      color: #1b2e4b;
      transition: all 0.2s ease-in-out; }
      @media (prefers-reduced-motion: reduce) {
        .df-breadcrumbs .breadcrumb-item a {
          transition: none; } }
    .df-breadcrumbs .breadcrumb-item.active {
      color: #0168fa; }
    .df-breadcrumbs .breadcrumb-item + .breadcrumb-item {
      padding-left: 8px; }
      .df-breadcrumbs .breadcrumb-item + .breadcrumb-item::before {
        color: #c0ccda;
        padding-right: 8px;
        font-weight: 500; }

.df-title {
  font-size: 32px;
  font-weight: 400;
  color: #001737;
  letter-spacing: -.5px;
  margin-bottom: 20px;
  text-indent: -2px; }
  @media (min-width: 576px) {
    .df-title {
      font-size: 36px; } }
  @media (min-width: 992px) {
    .df-title {
      font-size: 40px;
      margin-bottom: 35px; } }

.df-lead {
  color: #001737;
  letter-spacing: normal; }
  @media (min-width: 576px) {
    .df-lead {
      font-size: 18px;
      font-weight: 300;
      margin-bottom: 45px; } }
  @media (min-width: 1200px) {
    .df-lead {
      font-size: 20px; } }

.df-example {
  font-size: 0.875rem;
  letter-spacing: normal;
  padding: 10px;
  background-color: #fff;
  border: 1px solid rgba(72, 94, 144, 0.16);
  position: relative; }
  @media (min-width: 992px) {
    .df-example {
      padding: 20px; } }
  @media (min-width: 1200px) {
    .df-example {
      padding: 25px; } }
  .df-example::before {
    content: attr(data-label);
    display: block;
    position: absolute;
    top: -6px;
    left: 5px;
    font-size: 8px;
    font-weight: 600;
    font-family: -apple-system, BlinkMacSystemFont, "Inter UI", Roboto, sans-serif;
    letter-spacing: 1px;
    text-transform: uppercase;
    background-color: inherit;
    color: #8392a5;
    padding: 0 5px; }
  .df-example.df-inverse {
    background-color: #1c273c;
    color: rgba(255, 255, 255, 0.7);
    border-width: 0; }
    .df-example.df-inverse::before {
      background-color: #3b4863;
      top: -16px;
      left: 0; }

.section-nav {
  position: fixed;
  top: 60px;
  bottom: 0;
  right: 0;
  width: 240px;
  padding: 30px;
  display: none; }
  @media (min-width: 1200px) {
    .section-nav {
      display: block;
      border-left: 1px solid rgba(72, 94, 144, 0.16); } }
  .section-nav .nav-label {
    font-size: 10px;
    font-weight: 500;
    font-family: -apple-system, BlinkMacSystemFont, "Inter UI", Roboto, sans-serif;
    text-transform: uppercase;
    letter-spacing: .7px;
    color: #8392a5;
    display: block;
    margin-bottom: 15px; }
  .section-nav .nav-link {
    color: #1b2e4b;
    padding: 0;
    display: block;
    position: relative;
    white-space: nowrap;
    font-size: 13px; }
    .section-nav .nav-link:hover {
      color: #0168fa; }
    .section-nav .nav-link + .nav-link {
      margin-top: 5px; }
    .section-nav .nav-link.active {
      color: #0168fa;
      font-weight: 500;
      letter-spacing: -.12px; }
      .section-nav .nav-link.active::after {
        content: '';
        position: absolute;
        top: 50%;
        right: -31px;
        margin-top: -.5px;
        background-color: #0168fa;
        height: 1px;
        width: 30px; }

.demo-avatar-group {
  display: flex;
  align-items: center; }
  .demo-avatar-group .avatar {
    flex-shrink: 0; }
    .demo-avatar-group .avatar + .avatar {
      margin-left: 5px; }
      @media (min-width: 576px) {
        .demo-avatar-group .avatar + .avatar {
          margin-left: 10px; } }

.table-components {
  border: 1px solid rgba(72, 94, 144, 0.16); }
  .table-components thead th {
    font-size: 10px;
    font-family: -apple-system, BlinkMacSystemFont, "Inter UI", Roboto, sans-serif;
    letter-spacing: .5px;
    text-transform: uppercase;
    padding: 5px 10px;
    border-bottom: 0;
    border-color: rgba(72, 94, 144, 0.16);
    background-color: #f5f6fa;
    white-space: nowrap; }
  .table-components tbody td {
    padding: 8px 10px;
    border-color: rgba(72, 94, 144, 0.16);
    font-size: 0.875rem; }
    .table-components tbody td code, .table-components tbody td:first-child {
      color: #dc3545;
      font-size: 12px;
      font-family: 'Roboto Mono', monospace; }

.demo-btn-group {
  display: flex;
  align-items: center;
  flex-wrap: wrap; }
  .demo-btn-group .btn {
    margin-top: 5px;
    margin-right: 5px; }
    @media (min-width: 992px) {
      .demo-btn-group .btn {
        margin-top: 0; } }

.demo-icons-group i {
  font-size: 26px;
  line-height: .5; }
  .demo-icons-group i.far {
    font-size: 24px; }

.demo-modal-static {
  background-color: #97a3b9; }
  .demo-modal-static .modal {
    display: block;
    position: static; }

.demo-modal-btn {
  padding: 10px;
  border: 1px solid rgba(72, 94, 144, 0.16);
  background-color: #f1f2f6; }
  @media (min-width: 576px) {
    .demo-modal-btn {
      display: flex;
      justify-content: center; } }
  .demo-modal-btn .btn {
    display: flex;
    align-items: center;
    justify-content: center;
    text-transform: uppercase;
    font-size: 11px;
    font-weight: 500;
    font-family: -apple-system, BlinkMacSystemFont, "Inter UI", Roboto, sans-serif;
    letter-spacing: 1px; }
    .demo-modal-btn .btn + .btn {
      margin-top: 5px; }
      @media (min-width: 576px) {
        .demo-modal-btn .btn + .btn {
          margin-top: 0;
          margin-left: 5px; } }

@media (min-width: 992px) {
  .navbar-header-popover {
    z-index: 1080; } }

@media (min-width: 992px) {
  .content-popovers {
    height: calc(100vh - $height-header);
    overflow-y: auto;
    margin-right: 0;
    position: relative; } }

@media (min-width: 1200px) {
  .content-popovers {
    padding-right: 285px; } }

.section-nav-popovers {
  bottom: 0;
  z-index: 1000;
  background-color: #fff;
  border-left: 1px solid rgba(28, 39, 60, 0.06); }

.demo-static-toast .toast {
  opacity: 1; }

.demo-table .table th,
.demo-table .table td {
  white-space: nowrap; }

.demo-animate-media {
  flex-direction: column;
  align-items: stretch; }
  @media (min-width: 576px) {
    .demo-animate-media {
      flex-direction: row;
      align-items: stretch; } }
  .demo-animate-media .media-body {
    background-color: #f5f6fa;
    padding: 20px;
    display: flex;
    align-items: center;
    justify-content: center;
    order: 1; }

.demo-animate-list {
  padding-top: 10px;
  order: 2; }
  @media (min-width: 576px) {
    .demo-animate-list {
      order: 1;
      padding-top: 0;
      padding-right: 1px; } }
  .demo-animate-list .nav-link {
    padding: 7px 10px;
    background-color: #e5e9f2; }
    @media (min-width: 576px) {
      .demo-animate-list .nav-link {
        width: 150px; } }
    .demo-animate-list .nav-link:hover {
      background-color: #c0ccda;
      color: inherit; }
    .demo-animate-list .nav-link + .nav-link {
      margin-top: 1px; }
    .demo-animate-list .nav-link.active {
      background-color: #0168fa;
      color: #fff; }

.demo-animate-item {
  background-color: #3b4863;
  padding: 15px 20px;
  width: 175px;
  border-radius: 0.25rem; }
  .demo-animate-item .df-logo {
    color: #fff;
    letter-spacing: -1px; }
    .demo-animate-item .df-logo::before {
      flex-shrink: 0; }

.demo-forms .form-control,
.demo-forms .input-group-text {
  font-size: inherit; }

.morris-wrapper-demo {
  height: 200px;
  position: relative;
  margin-left: -15px;
  margin-right: -15px; }
  @media (min-width: 576px) {
    .morris-wrapper-demo {
      height: 300px; } }

.morris-donut-wrapper-demo {
  height: 200px; }
  @media (min-width: 576px) {
    .morris-donut-wrapper-demo {
      height: 250px; } }
