<?php
// session_start();
require("../includes/db_connect.php");
require_once("includes/session_token.php");

$accountId = $_SESSION['usr_accountId'];


?>
<!DOCTYPE html>
<html lang="en">

<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Community Bot Trade</title>
    <?php require_once("includes/header.php"); ?>

    <div class="content ht-100v pd-0">
        <div class="content-header center">
            <img src="../img/logo-white.png" class="aside-logo" style="width: 160px;" />
        </div><!-- content-header -->

        <div class="content-body">
            <div class="container pd-x-0">
                <div class="d-sm-flex align-items-center justify-content-between mg-b-20 mg-lg-b-25 mg-xl-b-30">
                    <div>
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb breadcrumb-style1 mg-b-10">
                                <li class="breadcrumb-item"><a href="account">Dashboard</a></li>
                            </ol>
                        </nav>
                        <h4 class="mg-b-0 tx-spacing--1">Community Bot Trade</h4>
                    </div>

                </div>

                <div class="row row-xs">
                    <div class="col-lg-6">
                        <div class="card">
                            <div class="card-body">
                                <div class="row">
                                    <div style="display: none;" id="errorPrompt" class="alert alert-danger col-md-12"
                                        role="alert">
                                        <p></p>
                                    </div>
                                    <div class="col-md-8 form-group">
                                        <label>Enter amount in USD</label>
                                        <input id="amount" type="text" class="form-control"
                                            placeholder="Enter amount here. (100+ USD)" required="">
                                        <div class="invalid-feedback amount_feedback">Amount cannot be empty.</div>
                                    </div>
                                    <div class="col-md-4 form-group" style="margin-top:33px;">
                                        <h2>USD</h2>
                                    </div>
                                </div>

                                <button id="proceed_btn" class="btn btn-brand-02 btn-block mg-b-10">Trade Now
                                    <span style="display: none;" class="button_spinner spinner-border spinner-border-sm"
                                        role="status" aria-hidden="false"></span>
                                    <span class="sr-only">Please wait...</span></button>

                            </div>
                        </div>
                    </div>
                </div>
            </div><!-- row -->
        </div><!-- container -->
    </div>
    </div>

    <?php require_once("includes/footer.php"); ?>
    <script type="text/javascript">
    $(document).ready(function() {
        var classes = $("#mn-trading").prop('class');
        $("#mn-trading").prop('class', classes + ' active pcoded-trigger');

        var classes = $("#mn-bot-trading").prop('class');
        $("#mn-bot-trading").prop('class', classes + ' active pcoded-trigger');

    });
    </script>
    <script src="../js/trade-bot.js?ver=<?php echo (rand()); ?>">
    </script>

    </body>

</html>