<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Automatic Trading</title>
    <meta name="description"
        content="Bots don't need sleep. Cryptotrading is 24/7. So is your bot. Give yourself an edge, and while everyone else sleeps, you’ll never miss a beat">
    <meta name="keywords" content="bot, sleep, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Automatic Trading</span>
                        <h1 class="uk-margin-remove">Bots don't need <span class="in-highlight">sleep.</span>
                        </h1>
                        <p class="uk-text-lead uk-text-muted">Cryptotrading is 24/7. So is your bot. Give yourself an
                            edge, and while everyone else
                            sleeps, you’ll never miss a beat.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="../create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/gifs/ft-1.gif" loop=infinite />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/aut-copy.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Copy</h6>
                                <p class="provider">A pro
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/aut-analyze.png" alt="award-2"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Analyze</h6>
                                <p class="provider">Autmatically</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/aut-247.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>24/7</h6>
                                <p class="provider">In the cloud</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-right uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/aut-like-a-pro.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <h1 class="uk-margin-small-bottom">Trade like <span class="in-highlight">a pro</span> without
                            being one.</h1>
                        <p class="uk-margin-top uk-text-lead grey">You don’t need to be a pro to trade like one. Level
                            up your game - and your results - by copying pro
                            traders on our marketplace. Subscribe to trading
                            signals, which tell your bot when to buy or sell.<br /><br />
                            Use strategies from professionals to scan the
                            markets, and download pre-configured bot
                            templates.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-src="img/in-equity-2-bg.png"
            data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-label uk-label-warning">Analyze automatically</span>
                        <h1 class="uk-margin-top">Find your ideal trading opportunity. Automatically, 24/7.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">Don’t let the fear of a market shift keep you up at
                            night. With our A.I., your bot can automatically
                            recognise trends and switch to a better strategy,
                            so you can rest easy. Create or download
                            strategies and let your Rocket watch the markets
                            for you, and buy or sell based on your
                            parameters.</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-uk-img
            style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-margin-bottom">
                            <img src="../img/in-lazy.gif" data-src="../img/icons/aut-cloud.png" alt="award-3"
                                style="width: 70px;" data-uk-img>
                        </span><br />
                        <p class="uk-margin-bottom uk-text-lead blue">
                            Cloud hosted
                        </p>
                        <h1 class="uk-margin-top">Available anytime. Anywhere.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">Hosted in the cloud, Rocketta is available
                            24/7. Protect and
                            monitor your assets, even while you’re logged out. Access your
                            Rocket from any device, including web, phone, tablet and even
                            your smartwatch.</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>