<footer>
    <!-- section content begin -->
    <div class="uk-section uk-section-primary uk-preserve-color in-equity-6 uk-background-contain uk-background-center"
        data-src1="../img/in-equity-decor-2.svg" data-uk-img
        style="max-width: unset;padding-top: 50px;padding-bottom: 50px;background: #0d0c43;">
        <div class="uk-container uk-margin-small-bottom" style="max-width:100vw;">

            <div class="uk-grid uk-flex uk-flex-center">
                <div class="uk-width-2xlarge@m uk-text-center">
                    <h1 class="white">As featured on</h1>
                </div>
            </div>

            <div class="uk-position-relative uk-visible-toggle uk-light uk-grid uk-flex uk-flex-center"
                style="display: flex;align-items: center;" tabindex="-1"
                uk-slider="autoplay: true;autoplay-interval: 3000">
                <ul class="uk-slider-items uk-child-width-1-2 uk-child-width-1-3@s uk-child-width-1-4@m"
                    style="display: flex; flex-direction: row; align-items: center;justify-content: center;">
                    <li>
                        <a href="https://techbullion.com/rocketta-announces-etf-trade-opportunity-for-september/"
                            target="_blank"><img src="../img/TechBullionLogo-3.png"></a>
                    </li>
                    <li>
                        <a href="https://www.marketwatch.com/press-release/rocketta-is-set-to-transform-tradefi-plans-partnerships-to-create-the-best-utility-for-ordinals-2023-05-30?mod=search_headline"
                            target="_blank">
                            <svg width="209" focusable="false" version="1.1" id="Layer_1"
                                xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px"
                                y="0px" viewBox="0 0 697.5 99.8" style="enable-background:new 0 0 697.5 99.8;"
                                xml:space="preserve" aria-labelledby="title--mwlogoHeader desc--mwlogoHeader"
                                role="img">
                                <title id="title--mwlogoHeader">MarketWatch Site Logo</title>
                                <desc id="desc--mwlogoHeader">A link that brings you back to the homepage.</desc>
                                <style type="text/css">
                                .mwA1 {
                                    fill: #ffffff;
                                }

                                .mwA2 {
                                    fill: #4db74d;
                                }
                                </style>
                                <g>
                                    <g>
                                        <path class="mwA1" d="M168.9,41.8l-1.2,5.9h-0.3c-1.5-3.3-5.7-7.9-15-7.9c-15,0-30.3,11.6-33.7,29.9c-2.9,16,4.8,30.1,22.6,30.1
                                    c6.5,0,14-2.5,17.9-8h0.3l-1.1,6H175l10.4-56H168.9z M163.5,69.7c-1.1,5.5-6.3,14.4-16.7,14.4c-10.2,0-12.3-9-11.4-14.2
                                    c1.2-6.4,6.9-14.4,16.6-14.4C161.5,55.6,164.7,63.1,163.5,69.7z"></path>
                                        <path class="mwA1" d="M194.8,41.8h15.6l-1.1,5.9h0.3c2-2.7,5.9-7.9,15.5-7.9l-3.1,17c-7.9,0.1-13.6,1.7-15.1,10.3l-5.7,30.7h-16.8
                                    L194.8,41.8z"></path>
                                        <polygon class="mwA1" points="236.4,19.9 253.2,19.9 245.3,62.1 245.6,62.1 265,41.8 284.7,41.8 259.1,66.4 273.8,97.8 254.8,97.8
                                    244,70.8 243.7,70.8 238.8,97.8 221.9,97.8"></polygon>
                                        <path class="mwA1"
                                            d="M311.6,39.8c-17,0-32.1,14.6-34.9,30.2c-3.1,16.6,8.1,29.7,24.2,29.7c5.7,0,11.6-1.7,16.8-5.1
                                    c5.3-3.2,10.2-8,14-14.3h-17.1c-2.8,2.9-6,5.2-11.2,5.2c-6.5,0-11.4-3.9-11.1-10.6h42c0.5-1.3,0.8-2.3,1.2-4.4
                                    C338.7,53.4,328.7,39.8,311.6,39.8z M294.6,63.6c1.3-3.3,5.9-9.6,14.6-9.6c8.7,0,10.8,6.3,10.8,9.6H294.6z">
                                        </path>
                                        <polygon class="mwA1" points="96.5,19.9 66.9,64.3 66.7,64.3 66.7,19.9 52.4,19.9 0,97.8 20.3,97.8 49.7,53.4 50,53.4 50,97.8
                                    64.4,97.8 93.8,53.4 94.1,53.4 94.1,97.8 110.9,97.8 110.9,19.9"></polygon>
                                        <path class="mwA1" d="M378,41.8h-10.6l3.1-16.6h-14.7l-1.2,6.4c-1.3,7.3-5.9,9.5-12,10.2h-0.1L340,54.5h8.3l-8,43.3H357l8-43.3
                                    h10.7L378,41.8z"></path>
                                    </g>
                                    <g>
                                        <g>
                                            <path class="mwA2"
                                                d="M637.2,76.6c-5.5,12.7-18.6,23.1-33.7,23.1c-17,0-27.5-13.4-24.5-30.1c3.1-16.4,18.3-29.8,35.1-29.8
                                        c14.8,0,25,9.9,25.3,23.6h-17c-1.1-3.9-3.6-7.9-10.7-7.9c-7.9-0.4-14.4,6.1-15.9,14.2c-1.5,8.2,2.7,14.3,10.7,14.3
                                        c6.9,0,11.1-4,13.5-7.5H637.2z M498.4,0l-32.6,19.9h9.2l-29.5,44.4h-0.3V19.9h-14.4l-29.5,44.4H401V19.9h-16.8v77.9h14.6
                                        l29.5-44.4h0.3v44.4h14.4l52.2-77.9h8.3L498.4,0z M530.2,97.8h-16.6l1.1-6h-0.3c-3.9,5.5-11.4,8-17.9,8
                                        c-17.8,0-25.5-14-22.6-30.1c3.3-18.3,18.7-29.9,33.7-29.9c9.2,0,13.5,4.5,15,7.9h0.3l1.2-5.9h16.6L530.2,97.8z M502,84.2
                                        c10.4,0,15.6-9,16.7-14.4c1.2-6.7-2-14.2-11.5-14.2c-9.6,0-15.4,8-16.6,14.4C489.7,75.2,491.8,84.2,502,84.2L502,84.2z
                                        M582.5,41.8H572l3.1-16.6h-14.7l-1.2,6.4c-1.3,7.3-5.9,9.5-12,10.2H547l-2.4,12.7h8.3l-8,43.3h16.7l8-43.3h10.7L582.5,41.8z
                                        M653,19.9h16.7l-5.1,27.8h0.3c3.6-5.2,8.4-7.9,15.8-7.9c5.3,0,11.4,2,14.2,6.3c3.6,5.5,3.2,10.4,1.3,20.4l-5.7,31.3h-16.7
                                        l5.6-30.5c0.5-2.7,2.1-11.8-6.8-11.8c-9.4,0-11,8.4-11.5,11.2l-5.7,31h-16.7L653,19.9z"></path>
                                        </g>
                                    </g>
                                </g>
                            </svg>
                        </a>
                    </li>
                </ul>
                <a class="uk-position-center-left uk-position-small uk-hidden-hover" href="#" uk-slidenav-previous
                    uk-slider-item="previous"></a>
                <a class="uk-position-center-right uk-position-small uk-hidden-hover" href="#" uk-slidenav-next
                    uk-slider-item="next"></a>
            </div>

        </div>
    </div>
    <!-- section content end -->

    <!-- footer content begin -->
    <div class="uk-section">
        <div class="uk-container uk-margin-top">
            <div class="uk-grid">
                <div class="uk-width-2-3@m">
                    <div class="uk-child-width-1-2@s uk-child-width-1-3@m" data-uk-grid>
                        <div>
                            <h5>Features</h5>
                            <ul class="uk-list uk-link-text">
                                <li><a href="../features/automatic-trading">Automatic Trading</a></li>
                                <li><a href="../features/algorithm-intelligence">Algorithm Intelligence</a></li>
                                <li><a href="../features/trading-terminal">Trading Terminal</a></li>
                                <li><a href="../features/dca">Dollar Cost Averaging</a></li>
                                <li><a href="../features/pro-tools">Pro tools</a></li>
                            </ul>
                        </div>
                        <div>
                            <h5>Solutions</h5>
                            <ul class="uk-list uk-link-text">
                                <li><a href="../solutions/miners-and-psps">Miners & PSPs</a></li>
                                <li><a href="../solutions/individuals">Individuals</a></li>
                                <li><a href="../solutions/advanced-traders">Advanced traders</a></li>
                            </ul>
                        </div>
                        <div class="in-margin-top-60@s">
                            <h5>Company</h5>
                            <ul class="uk-list uk-link-text">
                                <li><a href="../company/about">About Us</a></li>
                                <li><a href="../contact-us">Contact Us</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="uk-width-1-3@m uk-flex uk-flex-right@m">
                    <ul class="uk-list uk-link-text in-footer-socials">
                        <li><a href="https://www.facebook.com/Rocketta.io" class="fb-bg"><i
                                    class="fab fa-facebook-square"></i>Facebook</a></li>
                        <li><a href="https://www.youtube.com/channel/UCznROMgegrAkJPrF1zspX_g" class="yt-bg"><i
                                    class="fab fa-youtube"></i>Youtube</a></li>
                        <li><a href="https://www.linkedin.com/company/rocketta/" target="_blank" class="ld-bg"><i
                                    class="fab fa-linkedin"></i>Linkedin</a></li>
                        <li><a href="https://t.me/rockettaio" target="_blank" class="ld-bg"><i
                                    class="fab fa-telegram"></i>Telegram</a></li>
                        <li><a href="https://wa.me/message/77BFUI2XGVP4L1" target="_blank" style="background: #25D366"><i class="fab fa-whatsapp"></i> WhatsApp</a></li>
                    </ul>
                </div>
            </div>
        </div>
        <hr class="uk-margin-large">
        <div class="uk-container">
            <div class="uk-grid uk-flex uk-flex-middle">
                <div class="uk-width-2-3@m uk-text-small">
                    <ul class="uk-subnav uk-subnav-divider uk-visible@s" data-uk-margin>
                        <li><a href="../cookie-policy">Cookie policy</a></li>
                        <li><a href="../privacy-policy">Privacy policy</a></li>
                        <li><i class="fas fa-map-marker-alt fa-sm uk-margin-small-right"></i> Headquarters Address: 10
                            Wandsworth Rd, London, LND SW8 2LL</li>
                        <li><i class="fas fa-map-marker-alt fa-sm uk-margin-small-right"></i> Nordenskiöldsgatan 11, 211
                            19 Malmö, Sweden</li>
                        <li><i class="fas fa-envelope fa-sm uk-margin-small-right"></i> <a
                                href="mailto:support@rocketta.io" target="_blank">support@rocketta.io</a></li>
                        <li><i class="fas fa-phone fa-sm uk-margin-small-right"></i> <a href="tel:+442038053371">+44 20 3805 3371</a></li>
                    </ul>
                    <p class="copyright-text">©2023 Rocketta Incorporated. All Rights Reserved.</p>
                </div>
                <div class="uk-width-1-3@m uk-flex uk-flex-right uk-visible@m">
                    <span class="uk-margin-right"><img src="../img/in-lazy.gif"
                            data-src="../img/in-footer-mastercard.svg" alt="footer-payment" width="34" height="21"
                            data-uk-img></span>
                    <span><img src="../img/in-lazy.gif" data-src="../img/in-footer-visa.svg" alt="footer-payment"
                            width="50" height="16" data-uk-img></span>
                </div>
            </div>
        </div>
    </div>
    <!-- footer content end -->
    <!-- totop begin -->
    <div class="">
        <a href="#" class="in-totop left fas fa-chevron-up" data-uk-scroll></a>
    </div>
    <!-- totop end -->
</footer>
<!-- javascript -->
<script src="../js/jquery-3.5.1.min.js"></script>
<script src="../js/tether.min.js"></script>
<script src="../js/bootstrap.min.js"></script>
<script src="../js/vendors/uikit.min.js"></script>
<script src="../js/vendors/utilities.min.js"></script>
<script src="../js/vendors/trading-widget.min.js"></script>
<script src="../js/vendors/market-plugin.min.js"></script>
<!--<script src="../js/vendors/particles.min.js"></script>
    <script src="../js/config-particles.js"></script>-->
<script src="../js/config-theme.js"></script>
<script type="text/javascript">
  window.__lc = window.__lc || {};
  window.__lc.license = 15983334;
  ;(function(n,t,c){function i(n){return e._h?e._h.apply(null,n):e._q.push(n)};
  var e={_q:[],_h:null,_v:"2.0",on:function(){i(["on",c.call(arguments)])},once:function(){
  i(["once",c.call(arguments)])},off:function(){i(["off",c.call(arguments)])},
  get:function(){if(!e._h)throw new Error("[LiveChatWidget] You can't use getters before load.");
  return i(["get",c.call(arguments)])},call:function(){i(["call",c.call(arguments)])},init:function(){
  var n=t.createElement("script");
  n.async=!0,n.type="text/javascript",
  n.src="https://cdn.livechatinc.com/tracking.js",t.head.appendChild(n)}};
  !n.__lc.asyncInit&&e.init(),n.LiveChatWidget=n.LiveChatWidget||e}(window,document,[].slice))
</script>
<noscript>
<a href="https://www.livechatinc.com/chat-with/15983334/" rel="nofollow">Chat with us</a>,
powered by <a href="https://www.livechatinc.com/?welcome" rel="noopener nofollow" target="_blank">LiveChat</a>
</noscript>