<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>About Us</title>
    <meta name="description" content="Rocketta is the leading automated trading bot out there.
    Rocketta was founded in 2017 by a group of 4 Friends, 3 professional traders and 1 Engineer.">
    <meta name="keywords" content="miners, psps, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-src="img/in-equity-2-bg.png"
            data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-label uk-label-warning">About Us<i
                                class="fas fa-arrow-right fa-xs uk-margin-small-left"></i></span>
                        <h1 class="uk-margin-top">Rocketta is the leading <span class="in-highlight">automated
                                trading</span> bot out there.</h1>
                        <h4>Rocketta was founded in 2017 by a group of 4 Friends, 3
                            professional traders and 1 Engineer.</h4>
                        <p class="uk-text-lead uk-margin-medium-top">Alexander,
                            Alvarez,
                            Dorian,
                            Finn.</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center"
            style="background-color: #f7f7f7; padding-top:50px !important" data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-3-4@m uk-text-left">
                        <h1 class="uk-margin-top">Create magic</h1>
                        <p class="uk-text-lead uk-margin-medium-top">Mix a successful Daytrader with a brilliant
                            Engineer and you get the real m.a.g.i.c.
                            Cryptocurrency magic, to be exact.</p>
                        <p class="uk-text-lead uk-margin-medium-top">Finn did what every great Engineer would do:
                            automate it. Unconsciously creating
                            the ideal trader; unbeatable fast, reliable and - most importantly - always trading.
                            The fan base grew from family, friends and friends of friends to people all over the
                            world in no time. And then the realisation came; this might be something big.</p>
                        <p class="uk-text-lead uk-margin-medium-top">By making Rocketta public we were able to
                            help many traders create their
                            own magic. Would you like to try it out? Sign up for a free trial <a
                                href="../create-account">here</a>. Have fun</p>
                    </div>
                    <div class="uk-width-3-4@m uk-margin-medium-top">
                        <img class="uk-align-center" src="../img/in-lazy.gif" data-src="../img/rasp.jpg" alt="image"
                            width="758" height="334" data-uk-img>
                        <p class="uk-text-small uk-text-center uk-margin-medium-top">The first Rocketta</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center"
            style="padding-top:50px !important" data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-3-4@m uk-text-left">
                        <h1 class="uk-margin-top">How we got this far.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">Rocketta is an AI-driven bot that makes
                            crypto trading accessible, fun, and
                            worthwhile for everyone. We pursue perfection. Work hard. Learn every day.</p>
                        <p class="uk-text-lead uk-margin-medium-top">Join forces with our amazing team. And grow
                            rapidly. Together we optimize and
                            innovate a bot that hosts more than nine million transactions worth an estimated 2
                            billion USD each month.</p>
                        <p class="uk-text-lead uk-margin-medium-top">Would you like to join our team? Check out our
                            current job opportunities <a href="../login">here</a>.</p>
                    </div>
                    <div class="uk-width-3-4@m uk-margin-medium-top">
                        <img class="uk-align-center" src="../img/in-lazy.gif" data-src="../img/about-sec-1.jpg"
                            alt="image" width="758" height="334" data-uk-img>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center"
            style="padding-top:50px !important" data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-3-4@m uk-text-left">
                        <h1 class="uk-margin-top">This is the future.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">
                            <span class="uk-label uk-margin-small-left in-label-small">Miners</span>
                            <span class="uk-label uk-margin-small-left in-label-small">Nodes</span>
                            <span class="uk-label uk-margin-small-left in-label-small">Bulls</span>
                            <span class="uk-label uk-margin-small-left in-label-small">Bears</span>
                            <span class="uk-label uk-margin-small-left in-label-small">FOMO</span>
                            <span class="uk-label uk-margin-small-left in-label-small">FUD</span>
                        </p>
                        <p class="uk-text-lead uk-margin-medium-top">Some of those terms may sound like Marvel villains
                            or curse
                            words (“I should FUD you upside the head for staring at my
                            nodes!”). In our view – and yes, it’s a bold statement –</p>
                        <h4 class="blue">"Crypto will be the currency your grandkids consider the norm."</h4>
                        <p class="uk-text-lead uk-margin-medium-top">And for good reason, because however cryptic crypto
                            may
                            seem, the underlying Blockchain technology is as safe as
                            possible. No wonder everyone that joins us is instantly
                            hooked ;).</p>
                        <p class="uk-text-lead uk-margin-medium-top">Want to try the Rocket? Sign up for a free trial,
                            have a look
                            around, learn and most importantly, Have fun!</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>