  <!-- Favicon -->
  <link rel="shortcut icon" type="image/x-icon" href="../img/favicon.png">
  <!-- vendor css -->
  <link href="../lib/@fortawesome/fontawesome-free/css/all.min.css" rel="stylesheet">
  <link href="../lib/ionicons/css/ionicons.min.css" rel="stylesheet">
  <link href="../lib/jqvmap/jqvmap.min.css" rel="stylesheet">
  <link rel="stylesheet" href="../assets/vendors/bootstrap-datepicker/bootstrap-datepicker.min.css">


  <!-- DashForge CSS -->
  <link rel="stylesheet" href="../assets/css/dashforge.css">
  <link rel="stylesheet" href="../assets/css/dashforge.dashboard.css">
  <link rel="stylesheet" href="../assets/css/skin.charcoal.css">
  <!-- Chatra {literal} -->
  <script>
    (function(d, w, c) {
        w.ChatraID = '2etogsPTNBWSecDqX';
        var s = d.createElement('script');
        w[c] = w[c] || function() {
            (w[c].q = w[c].q || []).push(arguments);
        };
        s.async = true;
        s.src = 'https://call.chatra.io/chatra.js';
        if (d.head) d.head.appendChild(s);
    })(document, window, 'Chatra');
</script>
<!-- /Chatra {/literal} -->
  </head>

  <body class="page-profile">

      <aside class="aside aside-fixed">
          <div class="aside-header">
              <img src="../img/logo-white.png" class="aside-logo" style="width: 160px;" />
              <a href="" class="aside-menu-link">
                  <i data-feather="menu"></i>
              </a>
          </div>
          <div class="aside-body">
              <ul class="nav nav-aside">
                  <li id="mn-dashboard" class="nav-item"><a href="account" class="nav-link"><i
                              data-feather="pie-chart"></i>
                          <span>Dashboard</span></a></li>
                  <li id="mn-bot-softwares" class="nav-item"><a href="bot-softwares" class="nav-link"><i
                              data-feather="activity"></i>
                          <span>Bot Softwares</span></a></li>
                  <li id="mn-trading" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="bar-chart"></i> <span>Trading</span></a>
                      <ul>
                          <li id="mn-demo-trading"><a href="demo-trading">Demo</a></li>
                          <li id="mn-monthly-trading"><a href="monthly-trading">Monthly</a></li>
                          <li id="mn-quarterly-trading"><a href="quarterly-trading">Quarterly</a></li>
                          <li id="mn-annually-trading"><a href="annually-trading">Annually</a></li>
                          <li id="mn-bot-trading"><a href="bot-trading">Community Bot</a></li>
                      </ul>
                  </li>
                  <li id="mn-invoices" class="nav-item"><a href="invoices" class="nav-link"><i
                              data-feather="layers"></i>
                          <span>Invoices</span></a></li>
                  <li id="mn-wallet" class="nav-item"><a href="wallet" class="nav-link"><i
                              data-feather="credit-card"></i>
                          <span>Wallet</span></a></li>
                  <!-- bonus account -->
                  <li id="mn-bonus-history" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="bar-chart"></i> <span>Bonus Account</span></a>
                      <ul>
                          <li id="mn-bonus-account"><a href="bonus-account">Account</a></li>
                          <li id="mn-bonus-withdrawals"><a href="bonus-withdrawals">Withdrawals</a></li>
                          <li id="mn-bonus-transactions"><a href="bonus-transactions">Transactions</a></li>
                      </ul>
                  </li>
                  <!--<li id="mn-bot-account" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="bar-chart"></i> <span>Community Bot</span></a>
                      <ul>
                          <li id="mn-bot-account"><a href="bot-account">Account</a></li>
                          <li id="mn-bot-transactions"><a href="bot-transactions">Transactions</a></li>
                          <li id="mn-bot-withdrawals"><a href="bot-withdrawals">Withdrawals</a></li>
                          <li id="mn-bot-invoices"><a href="bot-invoices">Invoices</a></li>
                      </ul>
                  </li>-->
                  <li id="mn-charges" class="nav-item"><a href="charges" class="nav-link"><i
                              data-feather="dollar-sign"></i>
                          <span>Charges</span></a></li>
                  <li id="redeem-code" class="nav-item">
                      <a href="redeem-code" class="nav-link">
                          <i data-feather="dollar-sign"></i>
                          <span>Claim Redeem Code</span>
                      </a>
                  </li>
                  <li id="mn-transactions" class="nav-item"><a href="transactions" class="nav-link"><i
                              data-feather="briefcase"></i>
                          <span>Transactions</span></a></li>
                  <li id="mn-withdrawals" class="nav-item"><a href="withdrawals" class="nav-link"><i
                              data-feather="dollar-sign"></i>
                          <span>Withdrawals</span></a></li>
                  <li id="referrals" class="nav-item"><a href="referrals" class="nav-link"><i data-feather="users"></i>
                          <span>Referrals</span></a></li>
                  <li id="mn-identity-verification" class="nav-item"><a href="identity-verification" class="nav-link"><i
                              data-feather="user"></i>
                          <span>Identity Verification</span></a></li>
                  <li id="mn-settings" class="nav-item"><a href="profile-settings" class="nav-link"><i
                              data-feather="settings"></i>
                          <span>Settings</span></a></li>
                  <li class="nav-item"><a href="logout" class="nav-link"><i data-feather="power"></i>
                          <span>Log Out</span></a></li>
              </ul>
          </div>
      </aside>