<!-- section content begin -->
<div class="uk-section">
    <div class="uk-container">
        <div class="uk-grid">
            <div class="uk-width-1-1">
                <div class="uk-card uk-card-secondary uk-box-shadow-small uk-border-rounded uk-background-cover"
                    style="background-image: url(../img/in-card-background-1.jpg);">
                    <div class="uk-card-body">
                        <h2 class="uk-margin-remove-bottom">Start trading with Rocketta for free!</h2>
                        <p class="uk-margin-small-top">Free to use - no credit card required.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded" href="/create-account">Let's get
                            started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- section content end -->