<?php
// session_start();
require("../includes/db_connect.php");
require_once("includes/session_token.php");

$accountId = $_SESSION['usr_accountId'];

?>
<!DOCTYPE html>
<html lang="en">

<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Delete Account</title>
    <link rel="stylesheet" href="../css/bootstrap-select-country.min.css" />
    <link rel="stylesheet" href="../build/css/intlTelInput.css">

    <?php require_once("includes/header.php"); ?>


    <div class="content ht-100v pd-0">
        <div class="content-header center">
            <img src="../img/logo-white.png" class="aside-logo" style="width: 160px;" />
        </div>
        <div class="content-body">
            <div class="container pd-x-0">
                <div class="d-sm-flex align-items-center justify-content-between mg-b-20 mg-lg-b-25 mg-xl-b-30">
                    <div>
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb breadcrumb-style1 mg-b-10">
                                <li class="breadcrumb-item"><a href="account">Dashboard</a></li>
                            </ol>
                        </nav>
                        <h4 class="mg-b-0 tx-spacing--1">Delete Account</h4>
                    </div>
                </div>

                <div class="row row-xs">
                    <div class="col-md-3 col-lg-3 col-sm-12">
                        <div class="card">
                            <div class="card-body">
                                <nav class="nav nav-classic tx-13">
                                    <a id="mmn-profile-settings" href="profile-settings" class="nav-link"><i
                                            data-feather="user"></i> <span>Profile</span></a>
                                    <a id="mmn-change-password" href="change-password" class="nav-link"><i
                                            data-feather="lock" style="height: 50px;"></i> <span>Change
                                            Password</span></a>
                                    <a id="mmn-delete-account" href="delete-account" class="nav-link"><i
                                            data-feather="archive"></i> <span>Delete Account</span></a>

                                </nav>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-9 col-lg-9 col-sm-12">
                        <div class="card">
                            <div class="card-body">
                                <div id="pass_errorPrompt" class="alert alert-danger col-md-12" role="alert">
                                    <h5 style="color: #852b2b">Delete Account?</h5>
                                    <p style="margin-top: 30px; font-size: 15px">Make sure to withdraw all balances
                                        before deleting your account as this action will lead to permanent loss of data.
                                    </p>
                                </div>
                                <div class="col-md-6" style="margin-top: 40px">
                                    <label>Enter account password <br /><br /></label>
                                    <input id="password" type="password" class="form-control" placeholder=""
                                        required="">
                                    <div class="invalid-feedback password_feedback">Password cannot be empty.</div>
                                </div>
                                <div style="margin-top: 20px" class="col-md-12">
                                    <button class="btn btn-xs btn-danger flex-fill" id="delete_account_btn"
                                        style="font-size: .8125rem; font-weight: 600;">Yes Delete
                                        <span style="display: none;"
                                            class="button_spinner spinner-border spinner-border-sm" role="status"
                                            aria-hidden="false"></span>
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div><!-- content-body -->
    </div><!-- content -->

    <?php require_once("includes/footer.php"); ?>
    <script src="../build/js/intlTelInput.min.js"></script>
    <script src="../build/js/intlTelInput-jquery.min.js"></script>
    <script src="../js/bootstrap-select-country.min.js"></script>
    <script type="text/javascript">
    $(document).ready(function() {
        var classes = $("#mn-settings").prop('class');
        $("#mn-settings").prop('class', classes + ' active pcoded-trigger');

        var classes = $("#mmn-delete-account").prop('class');
        $("#mmn-delete-account").prop('class', classes + ' active pcoded-trigger');

    });
    </script>
    <script src="../js/delete-account.js"></script>

    </body>

</html>