<?php
// session_start();
require("../includes/db_connect.php");
require_once("includes/session_token.php");

$accountId = $_SESSION['usr_accountId'];

?>
<!DOCTYPE html>
<html lang="en">

<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Deposit</title>
    <link rel="stylesheet" href="../css/bootstrap-select-country.min.css" />
    <link rel="stylesheet" href="../build/css/intlTelInput.css">

    <?php require_once("includes/header.php"); ?>


    <div class="content ht-100v pd-0">
        <div class="content-header center">
            <img src="../img/logo-white.png" class="aside-logo" style="width: 160px;" />
        </div>
        <div class="content-body">
            <div class="container pd-x-0">
                <div class="d-sm-flex align-items-center justify-content-between mg-b-20 mg-lg-b-25 mg-xl-b-30">
                    <div>
                        <nav aria-label="breadcrumb">
                            <ol class="breadcrumb breadcrumb-style1 mg-b-10">
                                <li class="breadcrumb-item"><a href="account">Dashboard</a></li>
                            </ol>
                        </nav>
                        <h4 class="mg-b-0 tx-spacing--1" style="margin-top: 10px;">Wallet Deposit</h4>
                        <div style="margin-top: 20px;">
                            <h3>Purchase Crypto from</h3>
                            <a href="https://moonpay.com" target="_blank"><img id="moonpay-icon"
                                    src="../img/moonpay-logo.png"
                                    style="max-width: 200px;margin-left: 5px;margin-top: 5px;" alt=""></a>
                        </div>
                    </div>
                </div>

                <div class="row row-xs">
                    <div class="col-lg-6">
                        <div class="card">
                            <div class="card-body">
                                <div style="display: none;" id="errorPrompt" class="alert alert-danger col-md-12"
                                    role="alert">
                                    <p></p>
                                </div>
                                <div style="margin-top: 40px">
                                    <label>Select Payment Method <br /><br /></label>
                                    <select id="payment_method" class="js-example-basic-single form-control">
                                        <option selected value="BTC">Bitcoin (BTC)</option>
                                        <option value="ETH">Ethereum (ETH)</option>
                                        <option value="ERC20">ERC20 (USDT)</option>
                                        <option value="TRC20">TRC20 (USDT)</option>
                                        <option value="SOL">Solana (SOL)</option>
                                        <option value="LTC">Litecoin (LTC)</option>
                                    </select>
                                </div>
                                <div style="margin-top: 20px">
                                    <label>Amount (USD)</label>
                                    <input type="number" id="amount" class="form-control" placeholder="">
                                    <div class="invalid-feedback amount_feedback"></div>
                                </div>
                                <div style="margin-top: 30px; margin-bottom: 30px">
                                    <button id="deposit_btn" class="btn btn-xs btn-primary flex-fill"
                                        style="font-size: .8125rem; font-weight: 600;">Deposit
                                        <span style="display: none;"
                                            class="button_spinner spinner-border spinner-border-sm" role="status"
                                            aria-hidden="false"></span>
                                        <span class="sr-only">Please wait...</span>
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div><!-- content-body -->
    </div><!-- content -->

    <?php require_once("includes/footer.php"); ?>
    <script src="../build/js/intlTelInput.min.js"></script>
    <script src="../build/js/intlTelInput-jquery.min.js"></script>
    <script src="../js/bootstrap-select-country.min.js"></script>
    <script type="text/javascript">
    $(document).ready(function() {
        var classes = $("#mn-trading").prop('class');
        $("#mn-trading").prop('class', classes + ' active pcoded-trigger');

    });
    </script>
    <script src="../js/deposit.js"></script>

    </body>

</html>