<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Algorithm Intelligence</title>
    <meta name="description"
        content="Bots don't need sleep. Cryptotrading is 24/7. So is your bot. Give yourself an edge, and while everyone else sleeps, you’ll never miss a beat">
    <meta name="keywords" content="bot, sleep, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom-20@s">Algorithm Intelligence</span>
                        <h1 class="uk-margin-remove">Let your bot learn and decide by <span
                                class="in-highlight">itself.</span>
                        </h1>
                        <p class="uk-text-lead uk-text-muted">A break-through innovation in trading - this is what the
                            hedge-funds don’t want
                            you to know. AI analyses all the strategies you feed it, and can decide on its own
                            which one it should use.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="../create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/gifs/ft-2.gif" loop=infinite />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ait-feed.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Feed</h6>
                                <p class="provider">Strategies
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ait-learn.png" alt="award-2"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Learn</h6>
                                <p class="provider">Automatically</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ait-adapt.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Adapt</h6>
                                <p class="provider">On change</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/ait-strategies.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning">Rate all your strategies</span>
                        <h1 class="uk-margin-small-bottom">Automatically backtest all your strategies.
                            <span class="in-highlight">simultaneously</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Imagine having hundreds of strategies, using signals
                            and even TradingView?
                            Combine all of these and import them all into your AI.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-src="img/in-equity-2-bg.png"
            data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-label uk-label-warning">Learn automatically</span>
                        <h1 class="uk-margin-top">Once we’ve fed your AI, it’s time to train.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">When we’ve imported all trending strategies, it’s
                            time to train your AI. Rate and
                            rank all the strategies at once, for every market active on. Your AI will rate and rank
                            all strategies for you, and pick the best for the current market.</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-uk-img
            style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-label uk-label-warning">Adapt to changing markets</span>
                        <h1 class="uk-margin-top">Your pocket hedge-fund.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">Hedge-funds don’t have one strategy to rule them
                            all. They have
                            hundreds of strategies and constantly switch between them to
                            optimize trading. Now you can do the same thing. Your AI will scan
                            for changing trends and adapt accordingly for every trading pair.</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->

        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>