<?php
session_start();
$_SESSION['form-id'] = "iuibfbjaklsiabs";
?>

<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <title>Contact Us</title>
    <meta charset="utf-8">
    <meta name="description" content="Send us a message and we will respond as soon as possible.">
    <meta name="keywords" content="contact us, customer support, grnadhopperbot, Rocketta">
    <?php require_once("header2.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section">
            <div class="uk-container uk-margin-small-top uk-margin-bottom">
                <div class="uk-grid uk-flex uk-flex-center in-contact-6">
                    <div class="uk-width-3-5@m">
                        <div class="uk-grid uk-child-width-1-2@m uk-margin-medium-top uk-text-center" data-uk-grid>
                            <div>
                                <h5 class="uk-margin-remove-bottom"><i class="fas fa-map-marker-alt fa-sm uk-margin-small-right"></i>Address</h5>
                                  <p class="uk-margin-small-top">Headquarters: 10 Wandsworth Rd, London, LND SW8 2LL</p>
                                <p class="uk-margin-small-top">Nordenskiöldsgatan 11, 211 19 Malmö, Sweden</p>
                            </div>
                            <div>
                                <h5 class="uk-margin-remove-bottom"><i class="fas fa-envelope fa-sm uk-margin-small-right"></i>Email</h5>
                                <p class="uk-margin-small-top uk-margin-remove-bottom">support@rocketta.io</p>
                                <p class="uk-text-small uk-text-muted uk-text-uppercase">for public inquiries</p>
                            </div>
                        <div>
                                <h5 class="uk-margin-remove-bottom"><i class="fas fa-phone fa-sm uk-margin-small-right"></i>Phone</h5>
                                <p class="uk-margin-small-top uk-margin-remove-bottom"> +44 20 3805 3371 </p>
                                <p class="uk-text-small uk-text-muted uk-text-uppercase">for Calls and Messages</p>
                            </div>
                        </div>
                        <p class="uk-margin-remove-bottom uk-text-lead uk-text-muted uk-text-center">Have a question?
                        </p>
                        <h1 class="uk-margin-small-top uk-text-center">Let's <span class="in-highlight">get in
                                touch</span></h1>
                        <div style="display: none; margin-top: 20px;" id="responsePrompt">
                        </div>
                        <form id="contact-form" class="uk-form uk-grid-small uk-margin-medium-top" data-uk-grid>
                            <div class="uk-width-1-2@s uk-inline">
                                <span class="uk-form-icon fas fa-user fa-sm"></span>
                                <input class="uk-input uk-border-rounded" name="full_name" id="full_name" type="text"
                                    placeholder="Full name">
                            </div>
                            <div class="uk-width-1-2@s uk-inline">
                                <span class="uk-form-icon fas fa-envelope fa-sm"></span>
                                <input class="uk-input uk-border-rounded" id="email_address" name="email_address"
                                    type="email" placeholder="Email address">
                            </div>
                            <div class="uk-width-1-1 uk-inline">
                                <span class="uk-form-icon fas fa-pen fa-sm"></span>
                                <input class="uk-input uk-border-rounded" id="subject" name="subject" type="text"
                                    placeholder="Subject">
                            </div>
                            <div class="uk-width-1-1">
                                <textarea class="uk-textarea uk-border-rounded" id="message" name="message" rows="6"
                                    placeholder="Message"></textarea>
                            </div>
                            <div class="uk-width-1-1">
                                <button class="uk-width-1-1 uk-button uk-button-primary uk-border-rounded"
                                    id="send_message" type="submit" name="submit">Send Message <span
                                        style="display: none;" class="btn_spinner spinner-border spinner-border-sm"
                                        role="status" aria-hidden="false"></span></button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
    </main>
    <?php require_once("footer.php"); ?>
    <script src="js/app/contact-us.js"></script>
    </body>

</html>