#discountModal .uk-modal-body {
    background: #0d0c43;
    color: #fff !important;
}
.goog-te-banner-frame.skiptranslate {
  display: none !important;
}
.VIpgJd-ZVi9od-ORHb-OEVmcd {
  display: none !important;
}
.VIpgJd-ZVi9od-aZ2wEe-wOHMyf {
  display: none !important;
  visibility: hidden !important;
}
body {
 top: 0px !important; 
}
@media print {
  #google_translate_element {display: none;}
}
a.goog-te-menu-value {
  display: flex;
  align-items: center;
  color: #000 !important;
  font-size: 14px !important;
  padding: 4px;
}
.goog-te-gadget-icon {
  display: none;
}
 .mgm {
    border-radius: 7px;
    position: fixed;
    z-index: 1000;
    bottom: 40px;
    left: 40px;
    background: #fff;
    padding: 10px 27px;
    box-shadow: 0px 5px 13px 0px rgba(0, 0, 0, .3);
}

.mgm a {
    font-weight: 700;
    display: block;
}

.mgm a,
.mgm a:active {
    transition: all .2s ease;
    color: #f2d516;
}

/*.pricing-des{*/
/*    text-align:center;*/
/*}*/

.see-us-on-wrapper{
    display: flex;
    align-items: center;
    gap: 20px;
    padding-left: 0px;
}
.see-us-on{
    text-align: left;
    color: white;
    /* margin-left: 20%; */
    padding-left: 10px;
}
.see-us-on span{
    font-weight: bolder;
}
.see-us-on img{
    max-width: 250px;
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  [data-simplebar] {
 position:relative;
 z-index:0;
 overflow:hidden;
 -webkit-overflow-scrolling:touch
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  [data-simplebar=init] {
 display:-webkit-box;
 display:-ms-flexbox;
 display:flex
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-scroll-content {
 overflow-x:hidden;
 overflow-y:scroll;
 min-width:100%;
 -webkit-box-sizing:content-box;
 box-sizing:content-box
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-content {
 overflow-x:scroll;
 overflow-y:hidden;
 -webkit-box-sizing:border-box;
 box-sizing:border-box;
 min-height:100%
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-track {
 z-index:1;
 border-radius:7px;
 position:absolute;
 right:0;
 bottom:0;
 width:7px;
 background-color:#b0bec5
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-scrollbar {
 position:absolute;
 right:0;
 border-radius:7px;
 min-height:10px;
 width:7px;
 opacity:0;
 -webkit-transition:opacity .2s linear;
 transition:opacity .2s linear;
 background-color:#546e7a;
 background-clip:padding-box
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-track:hover .simplebar-scrollbar {
 opacity:.5;
 -webkit-transition:opacity 0 linear;
 transition:opacity 0 linear
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-track .simplebar-scrollbar.visible {
 opacity:.5
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-track.horizontal {
 left:0;
 width:auto;
 height:11px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .simplebar-track.vertical {
 top:0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .horizontal.simplebar-track .simplebar-scrollbar {
 right:auto;
 top:0;
 height:7px;
 min-height:0;
 min-width:10px;
 width:auto
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget-container {
 min-width:100%;
 font-family:'Open Sans',Helvetica,sans-serif!important;
 font-size:16px!important;
 line-height:1.416!important
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget-container--rtl {
 direction:rtl;
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget {
 width:100%;
 position:relative;
 -webkit-box-sizing:border-box;
 box-sizing:border-box;
 border-radius:2px;
 padding:16px;
 padding-right:7px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget::before {
 content:'';
 display:block;
 position:absolute;
 left:25px;
 right:25px;
 top:0;
 bottom:0;
 z-index:1
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark {
 background-color:#253137
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark::before {
 background-image:url(data:image/svg+xml;base64, );
 background-position:center center;
 background-repeat:no-repeat;
 opacity:.24
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light {
 background-color:#fafafa
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light::before {
 background-image:url(data:image/svg+xml;base64,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);
 background-position:center center;
 background-repeat:no-repeat
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__header,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__body,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer {
 position:relative;
 z-index:3
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__header {
 margin-bottom:14px;
 font-size:0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__header .ct-widget__tag {
 font-size:11px;
 line-height:1.3636;
 display:inline-block;
 padding:5px 10px;
 overflow:hidden;
 text-align:center
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__header .ct-widget__tag_tr {
 border-radius:0 2px 0 2px;
 margin:-16px -7px 0 0;
 float:right
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__posts {
 padding-right:11px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer {
 margin:5px -7px -16px -16px;
 padding:5px 2px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__powered {
 font-size:9px;
 font-weight:600;
 line-height:13px;
 display:inline-block;
 margin:0 10px;
 vertical-align:middle
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__poweredLink {
 text-decoration:underline
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__poweredLink:hover {
 text-decoration:none
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer>.ct-widget__powered {
 display:block;
 text-align:center
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency-rates {
 overflow:hidden;
 margin:-5px -2px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency-rates__row {
 text-align:left;
 overflow:hidden;
 font-size:0;
 padding:0 0 0 7px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency-rates.ct-currency-rates_mini .ct-currency {
 padding:3px 7px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency-rates.ct-currency-rates_big .ct-currency {
 padding:8px 7px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency {
 display:inline-block;
 vertical-align:middle;
 font-size:11px;
 line-height:15px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency .ct-currency__code {
 vertical-align:bottom
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency .ct-currency__price {
 margin:0 2px 0 0;
 font-weight:700;
 vertical-align:bottom
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency .ct-currency__indicator {
 vertical-align:bottom;
 padding:0 0 0 9px;
 display:inline-block;
 position:relative
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency .ct-currency__indicator i {
 position:absolute;
 vertical-align:middle
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency .ct-currency__indicator_down i {
 display:inline-block;
 border:4px solid transparent;
 border-top:5px solid;
 width:0;
 height:0;
 top:6px;
 left:0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-currency .ct-currency__indicator_up i {
 display:inline-block;
 border:4px solid transparent;
 border-bottom:5px solid;
 width:0;
 height:0;
 bottom:5px;
 left:0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-logotype {
 text-decoration:none!important;
 display:inline-block;
 vertical-align:middle
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post__meta {
 display:block
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post__text {
 margin:0;
 padding:0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post__link {
 text-decoration:none;
 color:inherit;
 font-size:12px;
 line-height:17px;
 display:inline-block
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post_text+.ct-post_text {
 border-top:1px solid;
 margin-top:16px;
 padding-top:6px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post_image {
 overflow:hidden
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post_image+.ct-post_image {
 margin-top:12px;
 padding-top:14px;
 border-top:1px solid
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post_image .ct-post__meta {
 float:left;
 width:85px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post_image .ct-post__image {
 display:block;
 max-width:100%;
 -webkit-box-shadow:0 2px 4px 0 rgba(0,0,0,.24);
 box-shadow:0 2px 4px 0 rgba(0,0,0,.24)
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-post_image .ct-post__text {
 margin-left:93px;
 font-weight:600
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark {
 color:#b0bec5
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-logotype {
 background:url(data:image/svg+xml;base64,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) no-repeat 0 0;
 width:25px;
 height:21px;
 background-size:25px 21px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-widget__tag {
 background:#465a65;
 color:#afbdc4
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-currency-rates {
 background-color:rgba(55,72,82,.9)
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-currency-rates .ct-currency__code {
 color:#fb0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-currency-rates .ct-currency__price {
 color:#fff
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-currency-rates .ct-currency__indicator_down {
 color:#ff919f
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-currency-rates .ct-currency__indicator_up {
 color:#7ed321
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-post {
 border-color:#2e3d44
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-widget__powered {
 color:#b0bec5
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_dark .ct-widget__poweredLink {
 color:#fb0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light {
 color:#253137
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-logotype {
 background:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNiAyNCI+PGcgZmlsbD0ibm9uZSI+PHBhdGggZmlsbD0iI0ZCMCIgZD0iTTEzLjM2NiAyMy4yNTNsMS40NS02LjIwNy00LjE5IDEuOTAzTDEzLjMzIDguMDI1SDguMzc3TDkuNDggMi44OWgxNS42N2wtMS4zMzYgNS4zMjhIMTguODZMMTcuNiAxMS4xMTJsNS42NDYtMi40MzUtOS44ODIgMTQuNTc2em0yLjUyLTcuNDk4bC0uODM4IDMuNjkzIDYuMTM4LTkuMDItNS4wMzQgMi4xMjggMi4xNzUtNS4xMDJoNC45MmwuOTUyLTMuODA2SDEwLjEyNmwtLjggMy42Mmg0Ljk1NmwtMi41NTMgMTAuMzUgNC4xNTYtMS44NjN6Ii8+PHBhdGggZmlsbD0iIzI1MzEzNyIgZD0iTTE0LjgwNCAxNy4wNTJsLTQuMTggMS44OTcuMDU4LS4yMjdjLS44Mi4yMi0xLjcxNi4zNC0yLjY1LjM0LTMuODUgMC02Ljk3Ny0yLjA1Ni02Ljk3Ny00LjU3di0uNzU0YzEuMjU3IDEuNzkgMy44OSAzLjA0NiA2Ljk3NyAzLjA0NiAxLjE2IDAgMi4yNi0uMTcgMy4yNS0uNDkzbC4yMi0uODgzYTkuOTE1IDkuOTE1IDAgMCAxLTMuNDcuNjEyYy0zLjg1IDAtNi45NzctMi4wNTYtNi45NzctNC41N3YtLjc2YzEuMjU3IDEuNzkgMy44ODUgMy4wNDcgNi45NzcgMy4wNDcgMS41MTcgMCAyLjkxNi0uMyA0LjA4OC0uODE2bC4yMjctLjkyM2MtMS4xOS42MjQtMi42OC45NzUtNC4zMTUuOTc1LTMuODUgMC02Ljk3Ny0yLjA1Ni02Ljk3Ny00LjU3di0uNzZjMS4yNTcgMS43OSAzLjg5IDMuMDQ4IDYuOTc3IDMuMDQ4IDEuODkgMCAzLjYtLjQ3NiA0Ljk1LTEuMjQ2bC4yNjUtMS4wODJjLTEuMzAyLjk2My0zLjE2IDEuNTctNS4yMTUgMS41Ny0zLjg1IDAtNi45NzctMi4wNTctNi45NzctNC41NyAwLTIuNTE1IDMuMTI2LTQuNTcgNi45NzctNC41NyAyLjQzNSAwIDQuNjE1LjgyIDUuODQ0IDIuMDk1aC45OEMxMy41NjMgMS4xOSAxMC45OC4wMzUgOC4wMy4wMzVjLTQuMjcgMC03Ljc0IDIuMzk2LTcuNzQgNS4zM3Y5LjMyNmMuMTUyIDIuODU1IDMuNTQ0IDUuMTM3IDcuNzQgNS4xMzcgMi45MTYgMCA1LjQ2LTEuMTEgNi43NzItMi43NzV6Ii8+PC9nPjwvc3ZnPg0K) no-repeat 0 0;
 width:23px;
 height:21px;
 background-size:23px 21px;
 overflow:hidden
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-widget__tag {
 background:#eceff1;
 color:#253137
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-post {
 border-color:#d7dddf
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-currency-rates {
 background-color:rgba(236,239,241,.8)
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-currency-rates .ct-currency__code {
 color:#546e7a
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-currency-rates .ct-currency__price {
 color:#253137
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-currency-rates .ct-currency__indicator_down {
 color:#d0021b
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-currency-rates .ct-currency__indicator_up {
 color:#417505
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-widget__powered {
 color:#546e7a
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_theme_light .ct-widget__poweredLink {
 color:#253137
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm::before,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md::before,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide::before,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg::before {
 background-position:center right
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm.ct-widget_images .ct-widget__body,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md.ct-widget_images .ct-widget__body,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide.ct-widget_images .ct-widget__body,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg.ct-widget_images .ct-widget__body {
 margin:0 0 0 -16px;
 overflow:hidden;
 font-size:0
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm .ct-post_image,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md .ct-post_image,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide .ct-post_image,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg .ct-post_image {
 border:0;
 padding-top:0;
 width:50%;
 display:inline-block;
 vertical-align:top;
 padding-left:16px;
 padding-right:16px;
 margin-bottom:16px;
 -webkit-box-sizing:border-box;
 box-sizing:border-box;
 margin-top:10px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm .ct-post__link,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md .ct-post__link,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide .ct-post__link,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg .ct-post__link {
 font-size:15px;
 line-height:20px;
 font-weight:400
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm .ct-widget__powered,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md .ct-widget__powered,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide .ct-widget__powered,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg .ct-widget__powered {
 text-align:left
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm .ct-widget__footer,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md .ct-widget__footer,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide .ct-widget__footer,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg .ct-widget__footer {
 margin-top:5px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_sm {
 max-width:768px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md {
 min-width:768px;
 max-width:1024px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_md_wide {
 min-width:768px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg {
 min-width:768px;
 max-width:1024px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg.ct-widget_images {
 min-width:1024px;
 max-width:1440px
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget.ct-widget_size_lg .ct-post_image {
 width:33.3333%
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer .ct-logotype {
 margin:5px 0 4px 5px;
 overflow:hidden
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer_yellow {
 background-color:#fabf2c
}
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer_yellow .ct-widget__powered,
#ct-news-informer-0fo79vupejxbjk0zjz7gycn  .ct-widget .ct-widget__footer_yellow .ct-widget__poweredLink {
 color:#253137
}