<?php
session_start();
if (!(isset($_SESSION['adm_accountId']))  || !(isset($_SESSION['adm_accessToken']))) {
	header('Location: ../login');
	exit();
}

function logOut()
{
	session_destroy();
	header('Location: ../login');
	exit();
}

if (isset($_GET['logout'])) {
	logOut();
}