<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Miners & PSPs</title>
    <meta name="description" content="Receiving funds on a wallet that needs to be exchanged automatically? Import
them automatically to Rocketta and convert them to the currency you wish.">
    <meta name="keywords" content="miners, psps, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Miners & PSPs</span>
                        <h1 class="uk-margin-remove">Automatically <span class="in-highlight">convert</span> funds.
                        </h1>
                        <p class="uk-text-lead uk-text-muted">Receiving funds on a wallet that needs to be exchanged automatically? Import them automatically to Rocketta and convert them to the currency you wish.
You can also save your coins on our stable coin in your wallet to avoid loses due to market fluctuations.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-convert.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/sol-mnp-convert.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Convert</h6>
                                <p class="provider">Payments you receive
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/sol-mnp-automatic.png"
                                    alt="award-2" style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Automatically</h6>
                                <p class="provider">24/7</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/sol-mnp-profit.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Profit</h6>
                                <p class="provider">When using trading tools</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-track.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Auto-import</span>
                        <h1 class="uk-margin-small-bottom">
                            Track payments <span class="in-highlight">automatically</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Auto-import payments that arrive on your exchange.
                            Track and convert them.
                            Exchange to your currency of choice.
                            All automatic.
                        </p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/login">Take a tour<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Track</span>
                        <h1 class="uk-margin-small-bottom">
                            <span class="in-highlight">24/7</span> monitoring.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Automatically adapt when a currency makes a move.
                            Track the price up, then sell
                            automatically when it goes down, set a tight stop-loss, or simply convert within a
                            certain timeframe.
                        </p>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-monitoring.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-currency.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Alter</span>
                        <h1 class="uk-margin-small-bottom">
                            Different settings per <span class="in-highlight">currency</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Tailor different settings for multiple currencies
                            with a config pool. Set different
                            stop-losses, and choose different ways of selling with a profit per coin. Use the
                            trailing stop-loss, take profit, or technical indicators to convert with a profit.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Personal support</span>
                        <h1 class="uk-margin-small-bottom">
                            We've got <span class="in-highlight">your back</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Get your own client success manager to make sure you
                            get the most out of
                            Rocketta, and even tell us directly what kind of features you’d like to have
                            added. Get instant access to our platinum service line.
                        </p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/login">Take a tour<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-support.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>