<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Advanced Traders</title>
    <meta name="description" content="Receiving funds on a wallet that needs to be exchanged automatically? Import
them automatically to Rocketta and convert them to the currency you wish.">
    <meta name="keywords" content="miners, psps, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Advanced Traders</span>
                        <h1 class="uk-margin-remove"><span class="in-highlight">Stay ahead</span> of the curve.
                        </h1>
                        <p class="uk-text-lead uk-text-muted">Take advantage of innovative tools that used to be
                            exclusive to big hedge funds. Use our pro tools to beat the rest, or capitalize on your
                            experience and become a seller on our marketplace.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-adv-ahead.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ttm-visual.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Create</h6>
                                <p class="provider">Trading rules
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ttm-convenience.png" alt="award-2"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Pro</h6>
                                <p class="provider">tools</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ait-learn.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Self-adapting</h6>
                                <p class="provider">Trading A.I</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-adv-trade.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Triggers</span>
                        <h1 class="uk-margin-small-bottom">Adapt automatically, by creating <span class="in-highlight">
                                trading rules</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Adapt automatically on market change. Decide what
                            needs to happen when
                            markets dip and set up an action. So you can rest easy while your bot works for
                            you.
                        </p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/login">Take a tour<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Strategy editor</span>
                        <h1 class="uk-margin-small-bottom">
                            <span class="in-highlight">Automate</span> your technical analysis.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Analyzing the markets with your technical indicators?
                            Automate it by letting your
                            Rocket scan the markets. Build strategies with your favorite indicators and
                            candlestick patterns, so your Rocket can take over.
                        </p>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/login-bg.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/dca-invest.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Pro tools</span>
                        <h1 class="uk-margin-small-bottom">
                            <span class="in-highlight">Profit</span> on market inefficiencies or a lack of liquidity.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">New markets often lack liquidity, which is solved
                            with Market-Making. Capitalize
                            on pair price differentials across exchanges with Arbitrage. Both available on
                            Rocketta.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Strategies & A.I</span>
                        <h1 class="uk-margin-small-bottom">
                            <span class="in-highlight">Scan the markets</span> . Automatically. And
                            adapt. Automatically.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Using technical analysis to decide when to buy and
                            sell?
                            Automate it by building strategies, using them to scan up to 75 markets
                            simultaneously. Feed your A.I. with these strategies, and let it learn by backtesting
                            them all. It’ll switch to the best performing one, automatically. Just like the hedge
                            funds do.
                        </p>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-adv-monitor.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/ait-strategies.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Marketplace seller</span>
                        <h1 class="uk-margin-small-bottom"><span class="in-highlight">Capitalize</span> on your
                            experience, and help thousands
                            across the globe.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Help traders across the globe and rent out your
                            experience to them. Sell your
                            strategies and templates, or send signals to which our users can subscribe to.
                            Some of our sellers earn over €100k per month.
                        </p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/login">Take a tour<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>