// <script type="text/javascript">
            var listCountries = ['United Kingdom', 'USA', 'Germany', 'France', 'Italy', 'USA', 'Australia', 'Lesotho',
                'Canada',
                'Argentina', 'Saudi Arabia', 'Mexico', 'Kenya', 'Maldives', 'Venezuela', 'South Africa', 'Sweden',
                'India',
                'South Africa', 'Italy', 'Pakistan', 'United Kingdom', 'South Africa', 'Greece', 'Cuba',
                'South Africa',
                'Portugal', 'Austria', 'South Africa', 'Panama', 'USA', 'South Africa', 'Netherlands',
                'Switzerland',
                'Belgium', 'Israel', 'Cyprus'
            ];
            var listPlans = ['$504,340.23', '$15,200.53', '$144,000.34', '$10,120.43', '$23,530.87', '$39,254.43', '$434,400.76', '$600,242.24', '$765,336.54', '$234,345.53'];
            interval = Math.floor(Math.random() * (40000 - 8000 + 1) + 8000);
            var run = setInterval(Withdrewrequest, interval);

            function Withdrewrequest() {
                clearInterval(run);
                interval = Math.floor(Math.random() * (40000 - 8000 + 1) + 8000);
                var country = listCountries[Math.floor(Math.random() * listCountries.length)];
                var plan = listPlans[Math.floor(Math.random() * listPlans.length)];
                var msg = 'Someone from <b>' + country +
                    '</b> just made a Withdrew of <strong href="javascript:void(0);" onclick="javascript:void(0);">' + plan +
                    ' </strong>';
                $(".mgm .txt").html(msg);
                $(".mgm").stop(true).fadeIn(2);
                window.setTimeout(function() {
                    $(".mgm").stop(true).fadeOut(100);
                }, 8000);
                run = setInterval(Withdrewrequest, interval);
            }
        // </script>

        // <script type="text/javascript">
            var listCountries = ['London', 'Carlifornia', 'Germany', 'France', 'Italy', 'USA', 'Australia', 'Lesotho',
                'Canada',
                'Argentina', 'Saudi Arabia', 'Mexico', 'Kenya', 'Maldives', 'Venezuela', 'Soweto', 'Sweden',
                'India',
                'South Africa', 'Italy', 'Pakistan', 'United Kingdom', 'South Africa', 'Greece', 'Cuba',
                'South Africa',
                'Delhi', 'Austria', 'South Africa', 'Panama', 'USA', 'South Africa', 'Netherlands', 'Switzerland',
                'Belgium', 'Israel', 'Cyprus'
            ];
            var listPlans = ['$120,430.66', '$120,567.15', '$110,430.62', '$101,060.91', '$170,602.43', '$52,540.43', '$74,020.12', '$20,320.43', '$90,320.24', '$45,040.97'];
            interval = Math.floor(Math.random() * (30000 - 8000 + 1) + 8000);
            var run = setInterval(depositrequest, interval);

            function depositrequest() {
                clearInterval(run);
                interval = Math.floor(Math.random() * (30000 - 8000 + 1) + 8000);
                var country = listCountries[Math.floor(Math.random() * listCountries.length)];
                var plan = listPlans[Math.floor(Math.random() * listPlans.length)];
                var msg = 'Someone from <b>' + country +
                    '</b> just made a deposit of <strong href="javascript:void(0);" onclick="javascript:void(0);">' + plan +
                    ' </strong>';
                $(".mgm .txt").html(msg);
                $(".mgm").stop(true).fadeIn(2);
                window.setTimeout(function() {
                    $(".mgm").stop(true).fadeOut(100);
                }, 8000);
                run = setInterval(depositrequest, interval);
            }
        // </script>

        // <script type="text/javascript">
            var listCountries = ['United Kingdom', 'USA', 'Germany', 'France', 'Italy', 'USA', 'Australia', 'Lesotho',
                'Canada',
                'Argentina', 'Saudi Arabia', 'Mexico', 'Kenya', 'Maldives', 'Venezuela', 'South Africa', 'Sweden',
                'India',
                'South Africa', 'Italy', 'Pakistan', 'United Kingdom', 'South Africa', 'Greece', 'Cuba',
                'South Africa',
                'Portugal', 'Austria', 'South Africa', 'Panama', 'USA', 'South Africa', 'Netherlands',
                'Switzerland',
                'Belgium', 'Israel', 'Cyprus'
            ];
            var listPlans = ['$40,300', '$68,202', '$4000', '$30,159', '$81,283', '$50,920', '$49,020', '$9300', '$79,500', '$9500','34,122.32','412,234.23'];
            interval = Math.floor(Math.random() * (40000 - 8000 + 1) + 8000);
            var run = setInterval(request, interval);

            function request() {
                clearInterval(run);
                interval = Math.floor(Math.random() * (40000 - 8000 + 1) + 8000);
                var country = listCountries[Math.floor(Math.random() * listCountries.length)];
                var plan = listPlans[Math.floor(Math.random() * listPlans.length)];
                var msg = 'Someone from <b>' + country +
                    '</b> just made a profits of <strong href="javascript:void(0);" onclick="javascript:void(0);">' + plan +
                    ' </strong>';
                $(".mgm .txt").html(msg);
                $(".mgm").stop(true).fadeIn(2);
                window.setTimeout(function() {
                    $(".mgm").stop(true).fadeOut(100);
                }, 8000);
                run = setInterval(request, interval);
            }
        // </script>
        
        function googleTranslateElementInit() {
            new google.translate.TranslateElement({pageLanguage: 'en', layout: google.translate.TranslateElement.InlineLayout.SIMPLE}, 'google_translate_element');
        }
        
        function changeGoogleStyles() {
            if(($goog = $('.goog-te-menu-frame').contents().find('body')).length) {
            var stylesHtml = '<style>'+'.goog-te-menu2 {'+
            'max-width:100% !important;'+
            'overflow:scroll !important;'+
            'box-sizing:border-box !important;'+
            'height:auto !important;'+
            '}'+
            '</style>';
        	$goog.prepend(stylesHtml);
        } else {
        	setTimeout(changeGoogleStyles, 50);
          }
        }
        changeGoogleStyles();