/*
 * Dashforge Auth Pages (Signin, Signup, etc.)
 *
 * This style is use in auth pages.
 *
 */
.content-auth {
  min-height: calc(100vh - 106px);
  display: flex;
  flex-direction: column;
  justify-content: center; }
  .content-auth > .container {
    padding: 0; }
    @media (max-width: 1139px) {
      .content-auth > .container {
        max-width: none;
        padding: 0 20px; } }
    .content-auth > .container:first-child {
      flex: 1; }

.content-auth-alt {
  min-height: calc(100vh - 106px);
  display: flex;
  flex-direction: column;
  justify-content: center; }
  .content-auth-alt .container {
    padding: 0; }
    @media (max-width: 1139px) {
      .content-auth-alt .container {
        max-width: none; } }

.sign-wrapper {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 800px; }
  @media (min-width: 1200px) {
    .sign-wrapper {
      width: 800px; } }
  .sign-wrapper .form-group label {
    display: block;
    margin-bottom: 5px; 
  }

  select {
    width: 100%;
    height: calc(1.5em + 0.9375rem + 2px);
    padding: 0.46875rem 0.625rem;
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.5;
    color: #596882;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid #c0ccda;
    border-radius: 0.25rem;
    transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
  }


