<?php
// session_start();
require("../includes/db_connect.php");
require_once("includes/admin_session_token.php");

// $accountId = $_SESSION['accountId'];


?>

<!DOCTYPE html>
<html lang="en">

<head>
  <title>Profit</title>

  <?php require("includes/header.php"); ?>



  <div class="content ht-100v pd-0">
    <div class="content-header">
    </div><!-- content-header -->

    <div class="content-body">
      <div class="container pd-x-0">
        <div class="d-sm-flex align-items-center justify-content-between mg-b-20 mg-lg-b-25 mg-xl-b-30">
          <div>
            <nav aria-label="breadcrumb">
              <ol class="breadcrumb breadcrumb-style1 mg-b-10">
                <li class="breadcrumb-item"><a href="#">Profit</a></li>
              </ol>
            </nav>
          </div>
        </div>

        <div class="row row-xs">
          <div class="col-sm-12">
            <div class="card">
              <div class="card-body">

                <div class="col-md-6">

                  <div style="display: none;" id="errorPrompt" class="alert alert-danger col-md-12" role="alert">
                    <p></p>
                  </div>
                  <div class="form-group" style="margin-top: 20px">
                    <label>Account ID</label>
                    <input type="text" id="accountId" class="form-control" placeholder="Enter account ID here">
                    <div class="invalid-feedback accountId_feedback">Account ID cannot be empty.</div>
                  </div>
                  <div class="form-group" style="margin-top: 20px;">
                    <label>Account</label>
                    <select id="account" class="custom-select">
                      <option selected value="monthly">Monthly</option>
                      <option value="annually">Annually</option>
                    </select>
                  </div>
                  <div class="form-group" style="margin-top: 20px">
                    <label>Amount (USD)</label>
                    <input type="text" id="amountUSD" class="form-control">
                    <div class="invalid-feedback amount_feedback">Amount cannot be empty.</div>
                  </div>
                  <div class="form-group" style="margin-top: 20px">
                    <label>Amount (BTC)</label>
                    <input type="text" id="amountBTC" class="form-control" disabled="True">
                  </div>

                  <div class="form-group" style="margin-top: 20px">
                    <button id="proceed_btn" class="btn btn-xs btn-primary flex-fill" style="font-size: .8125rem; font-weight: 600;">Proceed
                      <span style="display: none;" class="button_spinner spinner-border spinner-border-sm" role="status" aria-hidden="false"></span>
                      <span class="sr-only">Please wait...</span>
                    </button>
                  </div>

                </div>

              </div>
            </div>
          </div><!-- row -->
        </div><!-- container -->
      </div>
    </div>

    <div class="modal fade" id="modalProfit" tabindex="-1" role="dialog" aria-hidden="true">
      <div class="modal-dialog modal-dialog-centered wd-sm-400" role="document">
        <div class="modal-content">
          <div class="modal-body pd-20 pd-sm-40">
            <a href="" role="button" class="close pos-absolute t-15 r-15" data-dismiss="modal" aria-label="Close">
              <span aria-hidden="true">&times;</span>
            </a>

            <div>
              <h4>Add Profit?</h4>
              <div style="display: none;" id="profit_errorPrompt" class="alert alert-danger col-md-12" role="alert">
                <p></p>
              </div>
              <div class="form-group">
                <label id="profit_message"></label>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-secondary" style="width: 40%" data-dismiss="modal">Close</button>
                <button id="profit_btn" style="width: 40%" type="button" class="btn btn-primary btn-block">Yes, Profit
                  <span style="display: none;" class="profit_spinner spinner-border spinner-border-sm" role="status" aria-hidden="false"></span>
                  <span class="sr-only">Please wait...</span>
                </button>
              </div>

            </div>
          </div><!-- modal-body -->
        </div><!-- modal-content -->
      </div><!-- modal-dialog -->
    </div><!-- modal -->


    <?php require("includes/footer.php"); ?>
    <script src="../js/admin/profit.js"></script>

    </body>

</html>