<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Pro Tools</title>
    <meta name="description" content="Advanced trading techniques made available for everyone. Utilize pro tools that
were previously only available for professionals or developers.">
    <meta name="keywords" content="pro, tools, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Pro Tools</span>
                        <h1 class="uk-margin-remove">Leverage market
                            <span class="in-highlight">inefficiencies</span> or
                            <span class="in-highlight">liquidity</span>.
                        </h1>
                        <p class="uk-text-lead uk-text-muted">Advanced trading techniques made available for everyone.
                            Utilize pro tools that
                            were previously only available for professionals or developers.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="../create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/gifs/ft-5.gif" loop=infinite />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/prt-exchange.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Market arbitrage</h6>
                                <p class="provider">On one exchange
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/prt-exchanges.png" alt="award-2"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Exchange arbitrage</h6>
                                <p class="provider">Across exchanges</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/prt-access.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Market making</h6>
                                <p class="provider">Made accessible</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/prt-exchange.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Market Arbitrage</span>
                        <h1 class="uk-margin-small-bottom">
                            <span class="in-highlight">Leverage</span> price
                            inefficiencies on
                            your exchange.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Market Arbitrage enables you to take advantage of
                            price differences between pairs
                            on your exchange.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Exchange Arbitrage</span>
                        <h1 class="uk-margin-small-bottom">
                            Exchange Arbitrage,
                            <span class="in-highlight">without
                                withdrawals</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Execute exchange arbitrage between exchanges without
                            sending funds from one
                            exchange to another. Just connect the exchanges with appropriate funds,, enable
                            Exchange Arbitrage, and let your Rocket do the rest.
                        </p>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/prt-exchanges.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/prt-access.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Market-Making</span>
                        <h1 class="uk-margin-small-bottom">
                            Leverage <span class="in-highlight">big spreads</span>,
                            or create <span class="in-highlight">liquidity</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Market makers are the best friend of every exchange
                            or crypto
                            project. Now you can profit easily from a big spread, and make the
                            markets. A win-win for everybody.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>