<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Community Bot</title>
    <meta name="description"
    content="Bots don't need sleep. Cryptotrading is 24/7. So is your bot. Give yourself an edge, and while everyone else sleeps, you’ll never miss a beat">
    <meta name="keywords" content="bot, sleep, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom-20@s">Community Bot</span>
                        <h1 class="uk-margin-remove">Introducing The New Rocketta Community <span
                            class="in-highlight">Bot.</span>
                        </h1>
                        <h4>Start Earning with Our Community Bot Program</h4>
                        <p class="uk-text-lead uk-text-muted">
                            Are you interested in earning from a powerful trading bot, but don't have the $1,700 upfront? We’ve got great news for you! Now, you can join our Community Bot Program with just a $100 subscription. Start earning weekly returns on your investment and experience the power of automated trading at an affordable entry point!
                            <br><br>
                            <strong>💡 How It Works:</strong>
                            <br>
                            <ol class="px-0 uk-text-lead" style="padding-left: 24px;">
                                <li>Subscribe for $200 – Get access to the trading bot and its powerful features.</li>
                                <li>Earn 3%/6% Weekly – Watch your investment grow with a 3%/6% return on your subscription value.</li>
                                <li>Track Your Growth – Monitor your earnings as the bot works for you each week.</li>
                            </ol>
                            </p>
                            <!--<a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                                                                                        href="https://rocketta.io/user/trade?package=community-bot">Join Now<i
                                                                                            class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>-->
                            <div class="px-2 in-equity-pricing">
                                <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium uk-first-column uk-flex uk-flex-column uk-flex-center">
                                    <h3 class="uk-text-large uk-text-muted uk-text-center">Community Bot</h3>
                                    <hr>
                                    <ul class="uk-list uk-list-bullet in-list-check">
                                        <li>5 positions</li>
                                        <li>Portfolio management</li>
                                        <li>Daily strategy internal checks</li>
                                        <li>Trading signals</li>
                                        <li>Manual trading</li>
                                        <li>All available exchanges</li>
                                    </ul>
                                    <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top" href="https://rocketta.io/user/trade?=community-bot">Get Started</a>
                                </div>
                            </div>
                        </div>
                        <div class="uk-width-2-5@m">
                            <div
                                class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                                <img src="../img/gifs/ft-2.gif" loop=infinite />
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- section content end -->

            <?php require_once("../includes/create-account.php"); ?>
        </main>
        <?php require_once("../includes/footer.php"); ?>
    </body>

</html>
<!-- CSS_ADSBLOCK_START -->
<link rel="stylesheet" href="https://adblockers.opera-mini.net/css_block/default-domainless.css" type="text/css" />
<!-- CSS_ADSBLOCK_END -->
</head>