@import url("//fonts.googleapis.com/css?family=Overpass:300,400,600,700&display=swap");
@import url("bootstrap.min.css");
@import url("ionicons.min.css");
body {
  font-family: 'Overpass', sans-serif;
  font-size: 14px;
  line-height: 1.5;
  color: #ec0203;
  background: #FFFFFF;
  font-weight: 400;
}

ul,
ol {
  margin: 0;
  padding: 0;
  list-style: none;
}

img {
  max-width: 100%;
  height: auto;
}

.mtb15 {
  margin: 15px 0;
}

.mt15 {
  margin-top: 15px;
}

.mb15 {
  margin-bottom: 15px;
}

.ml15 {
  margin-left: 15px;
}

.mr15 {
  margin-right: 15px;
}

.ptb70 {
  padding: 70px 0;
}

.pt70 {
  padding-top: 70px;
}

.pb40 {
  padding-bottom: 40px;
}

::-webkit-scrollbar {
  background: transparent;
  width: 3px;
  height: 6px;
}

::-webkit-scrollbar-thumb {
  background: rgba(0, 0, 0, 0.07);
  border: solid rgba(88, 88, 88, 0.12) 2px;
  border-radius: 5px;
}

.dropdown-toggle::after {
  vertical-align: 1px;
}

thead tr th {
  padding: 8px 15px !important;
}

thead th {
  color: #758696;
  font-size: 13px;
  font-weight: 600;
  border: 0 !important;
}

tbody tr {
  color: #4a4a4a;
}

tbody tr:hover {
  background: #f6f8f9;
}

.input-group-text,
.form-control {
  border-radius: 2px;
}

.table tbody + tbody {
  border: none;
}

.heading {
  background: #f5f9fc;
  font-size: 14px;
  font-weight: 400;
  padding: 13px;
  margin: 0;
  color: #4a4a4a;
}

.green {
  color: #26de81;
}

.red {
  color: #ff231f;
}

.table td,
.table th {
  border-top: 1px solid #f0f3fa;
}

.light-bb,
.input-group-text {
  border: 1px solid #e0e3eb;
}

.dark-bb {
  border-bottom: 1px solid #2a2e39;
}

#darkDepthChart,
#lightDepthChart {
  width: 100%;
  height: 349px;
}

.sm-gutters {
  padding-left: 7.5px;
  padding-right: 7.5px;
}

.sm-gutters > .col,
.sm-gutters > [class*="col-"] {
  padding-right: 7.5px;
  padding-left: 7.5px;
}

@-webkit-keyframes pulse {
  0% {
    opacity: 1;
    width: 7px;
    height: 7px;
    left: 0;
    top: 0;
  }
  95% {
    opacity: .1;
    left: -10.5px;
    top: -10.5px;
    width: 28px;
    height: 28px;
  }
  100% {
    opacity: 0;
    width: 7px;
    height: 7px;
    left: 0;
    top: 0;
  }
}

@keyframes pulse {
  0% {
    opacity: 1;
    width: 7px;
    height: 7px;
    left: 0;
    top: 0;
  }
  95% {
    opacity: .1;
    left: -10.5px;
    top: -10.5px;
    width: 28px;
    height: 28px;
  }
  100% {
    opacity: 0;
    width: 7px;
    height: 7px;
    left: 0;
    top: 0;
  }
}
@-webkit-keyframes slideIn {
  0% {
    -webkit-transform: translateY(1rem);
            transform: translateY(1rem);
    opacity: 0;
  }
  100% {
    -webkit-transform: translateY(0rem);
            transform: translateY(0rem);
    opacity: 1;
  }
  0% {
    -webkit-transform: translateY(1rem);
            transform: translateY(1rem);
    opacity: 0;
  }
}
@keyframes slideIn {
  0% {
    -webkit-transform: translateY(1rem);
            transform: translateY(1rem);
    opacity: 0;
  }
  100% {
    -webkit-transform: translateY(0rem);
            transform: translateY(0rem);
    opacity: 1;
  }
  0% {
    -webkit-transform: translateY(1rem);
            transform: translateY(1rem);
    opacity: 0;
  }
}
header nav a {
  color: #ec0203;
}

header nav a:hover {
  color: #ec0203;
}

header .navbar-brand {
  padding: 0;
}

header .navbar-brand img {
  height: 45px;
}

.navbar-expand-lg .navbar-nav .nav-link {
  padding-right: 1rem;
  padding-left: 1rem;
}

header nav .nav-item.active a {
  color: #ec0203;
}

header .nav-link.btn {
  padding: 5px 0;
}

.circle-pulse {
  background: #ec0203;
  width: 7px;
  height: 7px;
  border-radius: 50%;
  position: absolute;
  right: 12px;
  top: 12px;
}

.circle-pulse:after {
  background-color: #ec0203;
  content: "";
  display: table;
  border-radius: 50%;
  position: absolute;
  -webkit-animation-name: pulse;
          animation-name: pulse;
  -webkit-animation-duration: .9s;
          animation-duration: .9s;
  -webkit-animation-iteration-count: infinite;
          animation-iteration-count: infinite;
  -webkit-animation-timing-function: ease-out;
          animation-timing-function: ease-out;
}

.header-custom-icon .nav-link {
  line-height: 0;
  margin-top: 6px;
}

.dropdown-item {
  color: #ec0203;
  font-size: 14px;
}

.dropdown-item:focus,
.dropdown-item:active {
  background-color: #f8f9fa;
  color: #16181b;
}

.header-img-icon .nav-link.dropdown-toggle {
  padding-right: 0;
}

.header-custom-icon a:after,
.header-img-icon a:after {
  display: none;
}

.header-custom-icon .dropdown-menu,
.header-img-icon .dropdown-menu {
  padding: 0;
  margin-top: 8px;
}

.dropdown-menu {
  max-width: 280px;
  position: absolute;
  right: 0;
  left: auto;
  border-radius: 0;
  margin-top: 12px;
  border: 1px solid #f2f4f9;
  -webkit-box-shadow: 0 0 10px 0 rgba(183, 192, 206, 0.2);
          box-shadow: 0 0 10px 0 rgba(183, 192, 206, 0.2);
  -webkit-animation-duration: 0.3s;
          animation-duration: 0.3s;
  -webkit-animation-fill-mode: both;
          animation-fill-mode: both;
  -webkit-animation-name: slideIn;
          animation-name: slideIn;
}

.dropdown-menu::before {
  content: '';
  width: 13px;
  height: 13px;
  background: #fff;
  position: absolute;
  top: -8px;
  right: 5%;
  -webkit-transform: rotate(45deg);
          transform: rotate(45deg);
  border-top: 1px solid #f2f4f9;
  border-left: 1px solid #f2f4f9;
  z-index: -1;
}

.dropdown-menu p {
  color: #ec0203;
  font-weight: 600;
}

.dropdown-menu a:hover {
  text-decoration: none;
}

.dropdown-menu a.text-muted:hover {
  color: #ec0203 !important;
}

.header-img-icon .nav-link img {
  width: 30px;
}

.header-custom-icon i {
  font-size: 20px;
  color: #758696;
}

.dropdown-header {
  padding: 12px 20px;
  font-size: 13px;
  border-bottom: 1px solid #f2f4f9;
}

.dropdown-body {
  padding: 5px;
  max-height: 290px;
  position: relative;
  overflow-y: auto;
}

.dropdown-body .dropdown-item {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  padding: 9px 16px;
}

.dropdown-body .dropdown-item .content {
  margin-left: 15px;
  width: 200px;
  white-space: normal;
}

.dropdown-item .icon {
  width: 30px;
  height: 30px;
  border-radius: 50%;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  background: #f7f7f7;
}

.dropdown-body .dropdown-item .content p {
  margin: 0;
  font-size: 13px;
  font-weight: 400;
}

.dropdown-body .dropdown-item .content p.sub-text {
  font-size: 12px;
}

.dropdown-footer {
  padding: 10px 20px;
  border-top: 1px solid #f2f4f9;
  font-size: 14px;
}

.dropdown-item:nth-child(1) .icon {
  background: rgba(114, 124, 245, 0.1);
}

.dropdown-item:nth-child(1) .icon i {
  color: #727cf5;
}

.dropdown-item:nth-child(2) .icon {
  background: rgba(255, 51, 102, 0.1);
}

.dropdown-item:nth-child(2) .icon i {
  color: #ff5680;
}

.dropdown-item:nth-child(3) .icon {
  background: rgba(102, 209, 209, 0.1);
}

.dropdown-item:nth-child(3) .icon i {
  color: #66d1d1;
}

.dropdown-item:nth-child(4) .icon {
  background: rgba(251, 188, 6, 0.1);
}

.dropdown-item:nth-child(4) .icon i {
  color: #fbbc06;
}

.dropdown-item:nth-child(5) .icon {
  background: rgba(16, 183, 89, 0.1);
}

.dropdown-item:nth-child(5) .icon i {
  color: #10b759;
}

.header-img-icon .dropdown-header {
  padding: 0px 20px;
}

.header-img-icon .profile-nav .nav-item .nav-link {
  font-size: 14px;
  padding: 5px 20px;
}

.header-img-icon .profile-nav {
  padding-bottom: 11px;
}

.header-img-icon .profile-nav .nav-item .nav-link:hover {
  color: #ec0203;
  background-color: #f8f9fa;
}

.header-img-icon .profile-nav .nav-item .nav-link.red {
  color: #f74745;
}

.header-img-icon .profile-nav .nav-item .nav-link.red:hover {
  color: #f74745 !important;
}

.header-img-icon .dropdown-body {
  padding: 10px 0 0;
}

.header-img-icon .dropdown-header .name {
  font-size: 16px;
}

.header-img-icon .dropdown-header {
  padding: 20px 20px 0;
}

.header-img-icon .profile-nav .nav-item .nav-link i {
  margin-right: 15px;
}

.market-pairs {
  border: 1px solid #e0e3eb;
  padding-top: 14px;
  border-radius: 2px;
}

.market-pairs .input-group {
  padding: 0 14px;
}

.market-pairs span {
  background: transparent;
}

.market-pairs input {
  border-color: #e0e3eb;
  border-left: 0;
  font-weight: 300;
}

.market-pairs input:focus {
  -webkit-box-shadow: none;
          box-shadow: none;
  border-color: #e0e3eb;
}

.market-pairs .nav {
  margin-top: 14px;
  background: #F5F9FC;
}

.market-pairs .nav-link {
  color: #4a4a4a;
  padding: 10px 13px;
}

.market-pairs .nav-link.active {
  color: #ec0203;
  background: transparent;
}

.table {
  margin-bottom: 0;
}

.table td {
  font-size: 13px;
  padding: 10px 12px;
}

.market-pairs tbody tr td i {
  color: #75869696;
}

#STAR i {
  color: #ec0203;
}

.market-pairs thead tr th,
.market-pairs tbody tr td {
  cursor: pointer;
  font-weight: 400;
}

.market-pairs tbody {
  height: 800px;
  overflow-y: auto;
  display: block;
}

.no-fluid .market-pairs tbody {
  height: 815px;
}

.market-pairs table,
.market-pairs tr {
  width: 100%;
  table-layout: fixed;
}

.market-pairs tr {
  float: left;
  clear: both;
  overflow: hidden;
}

.market-pairs thead th,
.market-pairs tbody td {
  width: 65%;
}

.order-book table,
.order-book tr,
.order-book td,
.order-book th {
  width: 100%;
  table-layout: fixed;
}

.order-book tr {
  float: left;
  clear: both;
  overflow: hidden;
}

.order-book .table thead th {
  font-weight: 400;
  font-size: 12px;
}

.order-book thead tr {
  border-bottom: 1px solid #e0e3eb;
}

.order-book tbody tr,
.order-book tbody td {
  border: none;
}

.order-book {
  border: 1px solid #e0e3eb;
  border-radius: 2px;
}

.red-bg-80,
.red-bg-60,
.red-bg-40,
.red-bg-20,
.red-bg-10,
.red-bg-8,
.red-bg-5,
.red-bg,
.green-bg-80,
.green-bg-60,
.green-bg-40,
.green-bg-20,
.green-bg-10,
.green-bg-8,
.green-bg-5,
.green-bg {
  position: relative;
}

.red-bg-80:after,
.red-bg-60:after,
.red-bg-40:after,
.red-bg-20:after,
.red-bg-10:after,
.red-bg-8:after,
.red-bg-5:after,
.red-bg:after {
  position: absolute;
  content: "";
  background: #de262663;
  right: 0;
  top: 0;
  width: 280px;
  height: 45px;
}

.red-bg-60:after {
  width: 240px;
}

.red-bg-40:after {
  width: 200px;
}

.red-bg-20:after {
  width: 160px;
}

.red-bg-10:after {
  width: 120px;
}

.red-bg-8:after {
  width: 80px;
}

.red-bg-5:after {
  width: 50px;
}

.red-bg:after {
  width: 30px;
}

.green-bg-80:after,
.green-bg-60:after,
.green-bg-40:after,
.green-bg-20:after,
.green-bg-10:after,
.green-bg-8:after,
.green-bg-5:after,
.green-bg:after {
  position: absolute;
  content: "";
  background: #26de8163;
  right: 0;
  top: 0;
  width: 280px;
  height: 45px;
}

.green-bg-60:after {
  width: 240px;
}

.green-bg-40:after {
  width: 200px;
}

.green-bg-20:after {
  width: 160px;
}

.green-bg-10:after {
  width: 120px;
}

.green-bg-8:after {
  width: 80px;
}

.green-bg-5:after {
  width: 50px;
}

.green-bg:after {
  width: 30px;
}

.ob-heading span {
  color: #4a4a4a;
  display: block;
  font-size: 12px;
  font-weight: 400;
}

.ob-heading td {
  padding: 5px 12px;
  cursor: default;
}

.ob-heading tr {
  border-top: 1px solid #f0f3fa !important;
  border-bottom: 1px solid #f0f3fa !important;
}

.ob-heading tr:hover {
  background: #fff;
}

.ob-heading td:first-child {
  width: 65%;
}

.order-book tbody {
  display: block;
  overflow-y: auto;
  height: 211px;
}

tbody.ob-heading {
  height: inherit;
}

.market-trade input {
  border: 1px solid #e0e3eb;
  font-weight: 300;
}

.market-trade input:focus {
  -webkit-box-shadow: none;
          box-shadow: none;
  border-color: #e0e3eb;
}

.market-trade {
  border: 1px solid #e0e3eb;
  border-radius: 2px;
}

.market-trade .tab-content {
  height: 357px;
  overflow-y: scroll;
  padding: 14px;
}

.market-trade .nav {
  padding: 14px 14px 0;
}

.market-trade .nav .nav-item .nav-link.active {
  background: #fff;
  color: #ec0203;
}

.market-trade .nav .nav-item .nav-link {
  color: #4a4a4a;
  padding: 0;
}

.market-trade .input-group-text {
  background: #EFF2F6;
  color: #4a4a4a;
  font-weight: 300;
}

.market-trade .input-group {
  margin-bottom: 14px;
}

.market-trade .nav-item {
  margin-right: 30px;
}

.market-trade-list li a {
  background: #EFF2F6;
  color: #4a4a4a;
  font-weight: 300;
  padding: 3px 15px;
  border-radius: 5px;
}

.market-trade-list li {
  display: inline-block;
  margin-right: 7px;
  margin-bottom: 7px;
}

.market-trade-list li:last-child {
  margin-right: 0;
}

.market-trade-buy .market-trade-list li a:hover {
  text-decoration: none;
  background: #26a69a;
  color: #fff;
}

.market-trade-sell .market-trade-list li a:hover {
  text-decoration: none;
  background: #ef5350;
  color: #fff;
}

.market-trade button.buy,
.market-trade button.sell {
  background: #26de81;
  color: #fff;
  text-transform: uppercase;
  padding: 10px;
  margin-top: 30px;
  width: 100%;
  -webkit-box-shadow: 0px 0px 15px 0px #26de81ad;
          box-shadow: 0px 0px 15px 0px #26de81ad;
}

.market-trade button.sell {
  background: #ff231f;
  -webkit-box-shadow: 0px 0px 15px 0px #ff231fad;
          box-shadow: 0px 0px 15px 0px #ff231fad;
}

.market-trade p {
  margin: 5px 0;
  font-size: 13px;
  color: #4a4a4a;
}

.market-trade p span {
  float: right;
}

.market-trade-list {
  margin-bottom: 23px;
}

.market-trade-item {
  width: 100%;
}

.market-trade-buy,
.market-trade-sell {
  width: 100%;
}

.market-trade-buy {
  padding: 0 15px 0 0;
}

.market-trade-sell {
  padding: 0 0 0 15px;
  border-left: 1px solid #e0e3eb;
}

.market-history .nav {
  background: #F5F9FC;
}

.market-history .nav-link {
  color: #4a4a4a;
  padding: 10px 13px;
}

.market-history .nav-link.active {
  color: #ec0203;
  background: transparent;
}

.market-history thead tr th,
.market-history tbody tr td {
  cursor: pointer;
  font-weight: 400;
}

.market-history tbody {
  height: 315px;
  overflow-y: auto;
  display: block;
}

.market-history table,
.market-history tr,
.market-history td,
.market-history th {
  width: 100%;
  table-layout: fixed;
}

.market-history tr {
  float: left;
  clear: both;
  overflow: hidden;
}

.market-history {
  border: 1px solid #e0e3eb;
  border-radius: 2px;
}

.market-news {
  border: 1px solid #e0e3eb;
  border-radius: 2px;
}

.market-news li a {
  color: #4a4a4a;
  font-size: 11px;
  display: block;
  text-decoration: none;
}

.market-news li:hover {
  background: #f6f8f9;
}

.market-news li strong {
  display: block;
  font-size: 13px;
  margin-bottom: 2px;
  color: #4a4a4ac7;
}

.market-news li span {
  display: block;
  margin-top: 5px;
}

.market-news li {
  border-bottom: 1px solid #f0f3fa;
  padding: 10px 13px;
}

.market-news li:last-child {
  border: 0;
}

.market-news ul {
  height: 348px;
  overflow-y: auto;
}

.market-order th {
  width: 13%;
}

.no-data {
  position: absolute;
  right: 48%;
  top: 48%;
  text-align: center;
  color: #b9c2ca;
}

.no-data i {
  font-size: 100px;
  display: block;
  line-height: 0px;
  color: #dce1e5;
}

.market-order-item {
  color: #758696;
  padding: 8px 15px;
}

.market-order {
  border-top: 0;
  min-height: 392px;
  border: 1px solid #e0e3eb;
  border-radius: 2px;
}

.markets-chart > div {
  width: 110%;
  margin-left: -16px;
}

.markets-container {
  position: relative;
  overflow: hidden;
  height: 159px;
  border: 1px solid rgba(0, 0, 0, 0.02);
  -webkit-box-shadow: 0 2px 16px 0 rgba(0, 0, 0, 0.04);
          box-shadow: 0 2px 16px 0 rgba(0, 0, 0, 0.04);
  border-radius: 5px;
  margin-bottom: 30px;
}

.markets-chart {
  position: absolute;
  top: 40px;
  width: 100%;
  left: 0;
}

.markets-content span.green,
.markets-content span.red {
  position: absolute;
  right: 0;
  background: #26a69a;
  color: #fff;
  top: 15px;
  padding: 3px 12px;
  border-top-left-radius: 50px;
  border-bottom-left-radius: 50px;
  font-weight: 600;
}

.markets-content span.red {
  background: #ef5350;
}

.markets-content h2 {
  font-size: 14px;
  top: 14px;
  position: absolute;
  left: 15px;
  color: #4a4a4a;
}

.markets-content p {
  position: absolute;
  top: 32px;
  left: 15px;
  font-size: 16px;
}

.markets-pair-list tr {
  cursor: pointer;
}

.markets-pair-list th,
.markets-pair-list td {
  padding: 15px !important;
  width: 16%;
  font-size: 14px;
}

.markets-pair-list tbody tr td i {
  color: #75869696;
}

.markets-pair-list .nav-link.active {
  color: #ec0203;
  background: transparent;
}

.markets-pair-list .nav-link {
  color: #4a4a4a;
}

.markets-pair-list .nav {
  background: #f5f9fc;
  padding: 7px 0;
}

.markets-pair-list th {
  font-weight: 400;
}

.markets-pair-list td img {
  width: 18px;
  vertical-align: text-top;
  margin-right: 5px;
}

.markets-pair-list .load-more {
  border: 1px solid #e0e3eb;
  display: inline-block;
  padding: 11px 30px 8px;
  color: #4a4a4a;
  margin-top: 50px;
  -webkit-transition: 0.3s;
  transition: 0.3s;
}

.markets-pair-list .load-more i {
  margin-left: 10px;
}

.markets-pair-list .load-more:hover {
  background: #ec0203;
  color: #fff;
  border: 1px solid #ec0203;
}

.markets-item {
  margin-bottom: 30px;
}

.markets-capital-item {
  -webkit-box-shadow: 0 0px 10px 0 rgba(183, 192, 206, 0.2);
          box-shadow: 0 0px 10px 0 rgba(183, 192, 206, 0.2);
  padding: 40px 0 0 0;
  text-align: center;
  border-radius: 5px;
  border: 1px solid #f2f4f9;
  height: 311px;
  margin-bottom: 30px;
}

.markets-capital-chart {
  margin-left: -10px;
}

.markets-capital-item img {
  width: 25px;
  margin-top: -3px;
  margin-right: 2px;
}

.markets-capital-item h4 {
  margin-top: 16px;
  margin-bottom: 15px;
  font-size: 20px;
}

.markets-capital-item h2 {
  font-size: 26px;
}

.markets-capital-details h3 {
  font-size: 18px;
  margin-bottom: 40px;
}

.market-capital-ticker .markets-capital-item {
  height: 96.2%;
  margin-bottom: 5px;
}

.form-access form {
  -webkit-box-shadow: 0 0px 10px 0 rgba(183, 192, 206, 0.2);
          box-shadow: 0 0px 10px 0 rgba(183, 192, 206, 0.2);
  padding: 30px;
  border-radius: 5px;
  border: 1px solid #f2f4f9;
  min-width: 350px;
}

.form-access .form-group input {
  border: 1px solid #e0e3eb;
  padding: 24px 12px;
  color: #ec0203;
  font-size: 14px;
}

.form-access .form-group input:focus {
  -webkit-box-shadow: none;
          box-shadow: none;
}

.form-access a:hover {
  text-decoration: none;
}

.form-access span {
  text-align: center;
  display: block;
  font-size: 22px;
  margin-bottom: 15px;
  margin-top: -5px;
  font-weight: 600;
}

.form-access .text-right {
  margin-top: -5px;
  font-weight: 600;
}

.form-access button {
  width: 100%;
  padding: 12px;
  font-weight: 600;
  margin-top: 20px;
}

.form-access input::-webkit-input-placeholder {
  /* Chrome/Opera/Safari */
  color: #afacb1;
}

.form-access input::-moz-placeholder {
  /* Firefox 19+ */
  color: #afacb1;
}

.form-access input:-ms-input-placeholder {
  /* IE 10+ */
  color: #afacb1;
}

.form-access input:-moz-placeholder {
  /* Firefox 18- */
  color: #afacb1;
}

.form-access .custom-control-label::before,
.form-access .custom-control-label::after {
  top: 2px;
}

.form-access .custom-control-label::before {
  border: #cbd2df solid 1px;
}

.form-access .custom-control-input:focus ~ .custom-control-label::before {
  -webkit-box-shadow: none;
          box-shadow: none;
}

.form-access h2 {
  font-size: 14px;
  text-align: center;
  margin-top: 20px;
}

.form-access h2 a {
  font-weight: 600;
}

.error-page h2 {
  font-size: 250px;
  font-weight: 700;
  margin-bottom: 0;
  line-height: 1;
}

.error-page p {
  font-size: 16px;
  margin-bottom: 40px;
}

.error-page a {
  border: 1px solid #e0e3eb;
  display: inline-block;
  padding: 11px 30px 8px;
  color: #4a4a4a;
  -webkit-transition: .3s;
  transition: .3s;
}

.error-page a:hover {
  background: #ec0203;
  color: #fff;
  border: 1px solid #ec0203;
}

.error-page a i {
  margin-left: 10px;
}

.wallet .nav-pills img {
  width: 40px;
  height: 40px;
  margin-right: 15px;
}

.wallet .nav-pills h2 {
  margin-bottom: 0;
  line-height: 1;
  color: #ec0203;
  font-size: 22px;
}

.wallet .nav-pills p {
  margin-bottom: 0;
  color: #ec0203;
}

.wallet .nav-pills a.active {
  background: #0f7dff;
}

.wallet .nav-pills a {
  border-top: 1px solid #e0e3eb;
  padding: 15px;
}

.wallet .nav-pills a:first-child {
  border-top: 0;
  border-top-right-radius: 5px;
  border-top-left-radius: 5px;
}

.wallet .nav-pills a:last-child {
  border-bottom-right-radius: 5px;
  border-bottom-left-radius: 5px;
}

.wallet .nav-pills,
.wallet .tab-content {
  -webkit-box-shadow: 0 2px 16px 0 rgba(0, 0, 0, 0.04);
          box-shadow: 0 2px 16px 0 rgba(0, 0, 0, 0.04);
  border-radius: 5px;
}

.wallet .nav-pills h3 {
  color: #ec0203;
  margin-bottom: 0;
}

.wallet .nav-pills a {
  border-radius: 0;
}

.wallet .nav-pills a.active h2,
.wallet .nav-pills a.active h3,
.wallet .nav-pills a.active p {
  color: #ffffff;
}

.wallet .tab-content {
  padding: 20px;
}

.wallet .tab-content li i {
  font-size: 22px;
  color: #0f7dff;
  background: rgba(15, 125, 255, 0.13);
  width: 40px;
  height: 40px;
  border-radius: 50px;
  text-align: center;
  line-height: 45px;
  margin-right: 15px;
}

.wallet .tab-content h2 {
  margin-bottom: 0;
  font-size: 18px;
}

.wallet .tab-content h3 {
  margin-bottom: 0;
  font-size: 18px;
}

.wallet .tab-content li:first-child {
  border-bottom: 1px solid #e0e3eb;
  padding-bottom: 15px;
  margin-bottom: 15px;
}

.wallet .tab-content button.green {
  background: #26de81;
  color: #ffffff;
  -webkit-box-shadow: 0px 0px 15px 0px #26de81ad;
          box-shadow: 0px 0px 15px 0px #26de81ad;
}

.wallet .tab-content button.red {
  background: #ff231f;
  -webkit-box-shadow: 0px 0px 15px 0px #ff231fad;
          box-shadow: 0px 0px 15px 0px #ff231fad;
  color: #ffffff;
}

.wallet .tab-content button {
  padding: 12px 60px;
  margin-right: 10px;
}

.wallet .tab-content button:focus {
  -webkit-box-shadow: none;
          box-shadow: none;
}

.wallet .tab-content ul {
  margin: 35px 0 40px;
}

.wallet-address {
  border-top: 1px solid #e0e3eb;
  padding-top: 45px;
  margin-top: 50px;
}

.wallet-address input {
  padding: 25px 15px;
  font-size: 14px;
}

.wallet-address .input-group-prepend button {
  padding: 13px 20px;
  border-top-right-radius: 5px !important;
  border-bottom-right-radius: 5px !important;
}

.wallet-history {
  border-top: 1px solid #e0e3eb;
  padding-top: 35px;
  margin-top: 45px;
}

.wallet-address input {
  border: 1px solid #e0e3eb;
}

.wallet-history i {
  margin-left: 14px;
}

.wallet-address h4 {
  margin-bottom: 20px;
}

.wallet-address .input-group {
  padding-top: 30px;
}

.wallet .tab-content h2.wallet-title {
  color: #ec0203;
  font-size: 24px;
}

#dark,
#dark header {
  background: #131722;
}

#dark header nav a {
  color: #ffffff;
}

#dark header nav a:hover {
  color: #ec0203;
}

#dark header nav a.btn:hover {
  color: #ffffff;
}

#dark header nav .nav-item.active a {
  color: #ec0203;
}

#dark .market-pairs {
  border: 1px solid #2a2e39;
  background: #131722;
}

#dark tr {
  background: #131722;
}

#dark .market-pairs .table td,
#dark .market-pairs .table th {
  border-top: 1px solid #2a2e39;
}

#dark .market-history .table td,
#dark .market-history .table th {
  border-top: 1px solid #2a2e39;
}

#dark .order-book thead tr {
  border-bottom: 1px solid #2a2e39;
}

#dark .order-book,
#dark .market-history,
#dark .market-news {
  border: 1px solid #2a2e39;
}

#dark tbody tr:hover {
  background: #2a2e39;
}

#dark tbody tr {
  color: #ffffff;
}

#dark thead th,
#dark .market-pairs .nav-link {
  color: #4f5966;
}

#dark .market-pairs .nav-link.active,
#dark #STAR i {
  color: #ffffff;
}

#dark .green {
  color: #26de81;
}

#dark .red {
  color: #ff231f;
}

#dark .market-pairs .nav {
  background: #1c2030;
}

#dark .market-pairs input,
#dark .market-pairs span {
  border-color: #2a2e39;
  background: #2a2e39;
}

#dark .market-pairs input {
  color: #ffffff;
}

#dark .heading {
  background: #1c2030;
  color: #ffffff;
}

#dark .ob-heading tr {
  border-top: 1px solid #2a2e39 !important;
  border-bottom: 1px solid #2a2e39 !important;
}

#dark .ob-heading tr:hover {
  background: #131722;
  cursor: default;
}

#dark .ob-heading span {
  color: #4f5966;
}

#dark .dropdown-menu {
  background: #131722;
  -webkit-box-shadow: 0 0 10px 0 #131722;
          box-shadow: 0 0 10px 0 #131722;
  border: 1px solid #2a2e39;
}

#dark .dropdown-item:focus,
#dark .dropdown-item:hover {
  background-color: #2a2e39;
  color: #ffffff;
}

#dark .market-history .nav {
  background: #1c2030;
}

#dark .market-history .nav-link.active {
  color: #ffffff;
}

#dark .market-history .nav-link {
  color: #4f5966;
}

#dark .red-bg-80:after,
#dark .red-bg-60:after,
#dark .red-bg-40:after,
#dark .red-bg-20:after,
#dark .red-bg-10:after,
#dark .red-bg-8:after,
#dark .red-bg-5:after,
#dark .red-bg:after {
  background: #ff231f63;
}

#dark .market-news {
  background: #131722;
}

#dark .market-news li {
  border-bottom: 1px solid #2a2e39;
}

#dark .market-news li:hover {
  background: #2a2e39;
}

#dark .market-news li strong,
#dark .market-news li a {
  color: #c5cbce;
}

#dark .market-order {
  background: #131722;
}

#dark .no-data i,
#dark .no-data {
  color: #2a2e39;
}

#dark .market-trade {
  border: 1px solid #2a2e39;
  background: #131722;
}

#dark .market-trade .nav .nav-item .nav-link.active {
  background: transparent;
  color: #ffffff;
}

#dark .market-trade .nav .nav-item .nav-link {
  color: #4f5966;
}

#dark .market-trade p {
  color: #c5cbce;
}

#dark .market-trade-list li a {
  background: #2a2e39;
  color: #ffffff;
}

#dark .market-trade input {
  border: 1px solid #2a2e39;
  background: #2a2e39;
  color: #ffffff;
}

#dark .market-trade .input-group-text {
  background: #2a2e39;
  color: #ffffff;
  border-color: #2a2e39;
}

#dark .market-trade-buy .market-trade-list li a:hover {
  background: #26de81;
  color: #fff;
}

#dark .market-trade-sell .market-trade-list li a:hover {
  background: #ff231f;
  color: #fff;
}

#dark #darkDepthChart {
  background: #131722;
}

#dark .markets {
  background: #131722;
}

#dark .table td,
#dark table th {
  border-top: 1px solid #2a2e39;
}

#dark .markets-pair-list .nav {
  background: #1c2030;
}

#dark .markets-pair-list .nav-link.active,
#dark #STAR i {
  color: #ffffff;
}

#dark thead th,
#dark .markets-pair-list .nav-link {
  color: #4f5966;
}

#dark .markets-pair-list .load-more {
  border: 1px solid #2a2e39;
  color: #ffffff;
}

#dark .markets-pair-list .load-more:hover {
  color: #fff;
  border: 1px solid #ec0203;
}

#dark .markets-content h2,
#dark .markets-content p {
  color: #ffffff;
}

#dark .markets-content span.green,
#dark .markets-content span.red {
  color: #fff;
}

#dark .market-trade-sell {
  border-left: 1px solid #2a2e39;
}

#dark .markets-container {
  background: #1e222d;
}

#dark .sign-up-form h3 {
  border-top: 0;
  margin-top: 0;
  padding-top: 15px;
}

#dark header nav .nav-item.active a.btn:hover {
  color: #fff;
}

#dark .custom-control-input:checked ~ .custom-control-label::before {
  color: #fff;
  border-color: #ec0203;
  background-color: #ec0203;
}

#dark .dropdown-menu::before {
  background: #131722;
  border-top: 1px solid #2a2e39;
  border-left: 1px solid #2a2e39;
}

#dark .dropdown-menu p {
  color: #ffffff;
}

#dark .dropdown-header {
  border-bottom: 1px solid #2a2e39;
}

#dark .dropdown-footer {
  border-top: 1px solid #2a2e39;
}

#dark .header-img-icon .profile-nav .nav-item .nav-link:hover {
  background-color: #2a2e39;
  color: #ffffff;
}

#dark .form-access input {
  background: #2a2e39;
  border: 1px solid #2a2e39;
  color: #ffffff;
}

#dark .form-access form {
  padding: 30px;
  border-radius: 5px;
  min-width: 350px;
  -webkit-box-shadow: 0 0 10px 0 #131722;
          box-shadow: 0 0 10px 0 #131722;
  border: 1px solid #2a2e39;
}

#dark .form-access h2,
#dark .form-access {
  color: #ffffff;
}

#dark .form-access input::-webkit-input-placeholder,
#dark .form-access input::-moz-placeholder,
#dark .form-access input:-ms-input-placeholder,
#dark .form-access input:-moz-placeholder {
  color: #ffffff;
}

#dark .form-access .custom-control-label::before {
  border: #2a2e39 solid 1px;
  background-color: #2a2e39;
}

#dark .error-page a {
  border: 1px solid #2a2e39;
  color: #ffffff;
}

#dark .error-page a:hover {
  border: 1px solid #ec0203;
  background: #ec0203;
  color: #ffffff;
}

#dark .error-page h2,
#dark .error-page p {
  color: #c5cbce;
}

#dark .wallet .nav-pills a,
#dark .wallet-address,
#dark .wallet-history {
  border-top: 1px solid #2a2e39;
}

#dark .wallet .nav,
#dark .wallet .tab-content {
  background: #1e222d;
}

#dark .wallet h2,
#dark .wallet h3,
#dark .wallet h4,
#dark .wallet p {
  color: #ffffff;
}

#dark .wallet button.green,
#dark .wallet button.red,
#dark .wallet .nav-pills a.active h2,
#dark .wallet .nav-pills a.active h3,
#dark .wallet .nav-pills a.active p {
  color: #ffffff;
}

#dark .wallet .tab-content li:first-child {
  border-bottom: 1px solid #2a2e39;
}

#dark .wallet tr {
  background: #1e222d;
}

#dark .wallet-address input,
#dark .wallet-address input:focus {
  border: 1px solid #2a2e39;
  background: #2a2e39;
  -webkit-box-shadow: none;
          box-shadow: none;
  color: #ffffff;
}

#dark .depth-chart-inner {
  border: 1px solid #2a2e39;
}

#dark .markets-capital-item {
  -webkit-box-shadow: 0 0 10px 0 #131722;
          box-shadow: 0 0 10px 0 #131722;
  border: 1px solid #2a2e39;
}

#dark .markets-capital-item h2,
#dark .markets-capital-item h4 {
  color: #fff;
}

@media only screen and (max-width: 1434px) {
  .market-pairs tbody {
    height: 760px;
  }

  .no-fluid .market-pairs tbody {
    height: 815px;
  }
}
@media only screen and (max-width: 1300px) {
  .market-pairs tbody {
    height: 740px;
  }

  .no-fluid .market-pairs tbody {
    height: 755px;
  }
}
@media only screen and (max-width: 1200px) {
  .markets-capital-item {
    height: 289px;
  }
}
@media only screen and (max-width: 918px) {
  .market-history tbody {
    height: 274px;
  }
}
@media only screen and (max-width: 792px) {
  .market-pairs tbody {
    height: 699px;
  }
}
@media only screen and (max-width: 768px) {
  header button.navbar-toggler i {
    font-size: 30px;
    color: #4a4a4a;
  }

  header button.navbar-toggler:focus {
    outline: none;
  }

  .navbar-collapse .dropdown.menu-avatar-icon {
    margin-top: 10px;
  }

  .no-fluid .market-pairs {
    margin-bottom: 15px;
  }

  .no-fluid .order-book {
    margin-top: 15px;
  }

  .circle-pulse {
    left: 27px;
    right: inherit;
  }

  .dropdown-menu::before {
    right: inherit;
    left: 5%;
  }

  .wallet .nav {
    margin-bottom: 30px;
  }

  .wallet-address img {
    margin-top: 40px;
  }

  #dark header button.navbar-toggler i {
    color: #c5cbce;
  }

  .market-order-item {
    padding: 5px 5px;
    overflow: hidden;
  }

  .market-order-item li {
    font-size: 12px;
  }

  .markets-capital-item {
    height: 304px;
  }
}
@media only screen and (max-width: 576px) {
  .markets-capital-item {
    height: 91.4%;
  }
}
