<?php
session_start();
$trading_type = "";

if (isset($_GET["type"])) {
    $trading_type = $_GET["type"];
}
?>
<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Pricing</title>
    <meta name="description" content="Receiving funds on a wallet that needs to be exchanged automatically? Import
    them automatically to Rocketta and convert them to the currency you wish.">
    <meta name="keywords" content="pricing, psps, automatic, trading, Cryptotrading, trade">
    <style>
        .wrapper {
            text-align: center;
        }

        .tabs {
            padding: 0px;
            list-style: none;
            background: #fff;
            box-shadow: 0px 5px 20px rgba(0, 0, 0, 0.1);
            display: inline-block;
            border-radius: 50px;
            position: relative;
            font-size: 1rem;
            font-weight: 400;
            line-height: 1.5;
            color: #212529;
        }

        .tabs a {
            text-decoration: none;
            padding: 10px 20px;
            display: inline-block;
            position: relative;
            z-index: 1;
            transition-duration: 0.6s;
            font-size: 1rem;
            font-weight: 400;
            line-height: 1.5;
            color: #212529;
        }

        .tabs a.active {
            color: #fff;
        }

        .tabs a i {
            margin-right: 5px;
        }

        .tabs .selector {
            height: 100%;
            display: inline-block;
            position: absolute;
            left: 0px;
            top: 0px;
            z-index: 1;
            border-radius: 50px;
            transition-duration: 0.6s;
            transition-timing-function: cubic-bezier(0.68, -0.55, 0.265, 1.55);
            background: #0d0c43;
        }

        .tabs a:hover {
            color: #fff;
            text-decoration: none !important;
        }
    </style>

    <?php require("header2.php");
    ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-src="img/in-equity-2-bg.png"
            data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-label uk-label-warning">Pricing<i
                            class="fas fa-arrow-right fa-xs uk-margin-small-left"></i></span>
                        <h1 class="uk-margin-top"><span class="in-highlight">Compare</span> bots</h1>
                        <p class="uk-text-lead uk-margin-medium-top">
                            Choose a plan that fits you.<br />
                            All our plans include one free trading simulator.
                        </p>
                        <p class="uk-text-lead uk-margin-medium-top">
                            Expected returns of 100% - 400% monthly, the higher the software package, the higher the returns.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="wrapper uk-flex uk-flex-center uk-flex-middle px-4 uk-flex-wrap">
            <nav class="tabs uk-flex-none uk-flex-center" style="margin: 0 auto;">
                <div class="selector"></div>
                <a href="#" class="active">Monthly</a>
                <a href="#" id="quaterly-tab">Quarterly</a>
                <a href="#" id="annual-tab">Annually</a>
            </nav>
            <div class="uk-margin-small-top">
                <a class="uk-button uk-button-primary uk-border-rounded" href="features/community-bot">Community bot</a>
            </div>
        </div>


        <!-- monthly -->
        <div class="tab-content" id="tab-content-1" style="display: block;">
            <!-- section content begin -->
            <div class="uk-section in-equity-17" style="padding-top:50px !important">
                <div class="uk-container uk-margin-top uk-margin-medium-bottom" style="max-width:1300px">
                    <div class="uk-grid uk-flex uk-flex-center">
                        <div style="width: 100%;">
                            <div class="row uk-grid-collapse uk-child-width-1-4@m in-equity-pricing" data-uk-grid>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Explorer</h3>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">Demo
                                        </h2>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <li>20 positions</li>
                                            <li>portfolio management</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges</li>
                                        </ul>
                                        <a href="user/trade-demo"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-large">
                                        <div class="uk-container mt-4">

                                            <div class="uk-alert-primary" uk-alert>

                                                <a href class="uk-alert-close" uk-close></a>
                                                <p>
                                                    50% slash on the new bot price for the upcoming ETF the prices will go back to normal after the ETF
                                                </p>
                                            </div>
                                        </div>
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Ninja 3.6</h3>
                                        <p class="pricing-des">
                                            Works in the Gold market with a slightly more aggressive Grid strategy but with the usual hedging strategies in a minute timeframe.
                                        </p>

                                        <h3 class="uk-margin-top uk-text-center"><span class="in-highlight">50%</span> off</h3>

                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <del><sup>$</sup>3,400<sub>/mo</sub></del>
                                        </h2>

                                        <h2 class="uk-margin-top uk-margin-bottom uk-text-center">
                                            <sup>$</sup>1,700<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">Save $1,200 with
                                                quarterly plan</span>
                                        </p>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">Save $9,600 with
                                                annual plan</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <li>100 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>20 min strategy interval checks</li>
                                            <li>Scan markets with the power of 15 bots</li>
                                            <li>5 event based triggers</li>
                                            <li>Backtesting</li>
                                            <li>Paper (simulated) trading</li>
                                            <li>Trading signals</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges </li>
                                        </ul>
                                        <a href="user/trade?package=monthly-ninja"
                                            class="uk-button uk-button-primary uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">

                                        <div class="uk-container mt-4">
                                            <div class="uk-alert-primary" uk-alert>
                                                <a href class="uk-alert-close" uk-close></a>
                                                <p>
                                                    50% slash on the new bot price for the upcoming ETF the prices will go back to normal after the ETF
                                                </p>
                                            </div>
                                        </div>

                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Subzero 5.2</h3>
                                        <p class="pricing-des">
                                            Are automated Bot that helps you buy and sell cryptocurrencies at the correct time. The main goal of this Bot is to increase revenue.
                                        </p>

                                        <h3 class="uk-margin-top uk-text-center"><span class="in-highlight">50%</span> off</h3>

                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <del><sup>$</sup>7,200<sub>/mo</sub></del>
                                        </h2>

                                        <h2 class="uk-margin-top uk-margin-bottom uk-text-center">
                                            <sup>$</sup>3,600<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">Save $2,400 with
                                                quarterly plan</span>
                                        </p>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">Save $19,200 with
                                                annual plan</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>500 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all available exchanges</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->

                                            <li>500 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>10 min strategy interval checks</li>
                                            <li>Scan markets with the power of 50 bots</li>
                                            <li>7 event based triggers</li>
                                            <li>Backtesting</li>
                                            <li>Paper (simulated) trading</li>
                                            <li>Trading signals</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges</li>
                                        </ul>
                                        <a href="user/trade?package=monthly-subzero"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">

                                        <div class="uk-container mt-4">
                                            <div class="uk-alert-primary" uk-alert>
                                                <a href class="uk-alert-close" uk-close></a>
                                                <p>
                                                    50% slash on the new bot price for the upcoming ETF the prices will go back to normal after the ETF
                                                </p>
                                            </div>
                                        </div>
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Rocket 7.1</h3>
                                        <p class="pricing-des">
                                            Is an AI-driven bot that makes crypto trading accessible, fun, and worthwhile for everyone.
                                        </p>

                                        <h3 class="uk-margin-top uk-text-center"><span class="in-highlight">50%</span> off</h3>

                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <del><sup>$</sup>14,600<sub>/mo</sub></del>
                                        </h2>

                                        <h2 class="uk-margin-top uk-margin-bottom uk-text-center">
                                            <sup>$</sup>7,300<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">Save $3,150 with
                                                quarterly plan</span>
                                        </p>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">Save $25,200 with
                                                annual plan</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>1,000 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all coins for signals</li>-->
                                            <!--<li>market arbitrage</li>-->
                                            <!--<li>algorithm intelligence</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->
                                            <li>1,000 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>5 minute strategy interval checks</li>
                                            <li>Scan markets with the power of 75 bots</li>
                                            <li>15 event based triggers</li>
                                            <li>A.I. strategies and A.I designer</li>
                                            <li>manual trading</li>
                                            <li>all coins for trading signals</li>
                                            <li>market making & arbitrage</li>
                                            <li>Extra Technical Indicators</li>
                                            <li>algorithm intelligence</li>
                                        </ul>
                                        <a href="user/trade?package=monthly-rocket"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- section content end -->
        </div>
        <!-- end monthly -->
        <!-- monthly -->
        <div class="tab-content" id="tab-content-2" style="display: none;">
            <!-- section content begin -->
            <div class="uk-section in-equity-17" style="padding-top:50px !important">
                <div class="uk-container uk-margin-top uk-margin-medium-bottom" style="max-width:1300px">
                    <div class="uk-grid uk-flex uk-flex-center">
                        <div style="width: 100%;">
                            <div class="row uk-grid-collapse uk-child-width-1-4@m in-equity-pricing" data-uk-grid>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Explorer</h3>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">Demo
                                        </h2>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <li>20 positions</li>
                                            <li>portfolio management</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges</li>
                                        </ul>
                                        <a href="user/trade-demo"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-large">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Ninja 3.6</h3>
                                        <p class="pricing-des">
                                            Works in the Gold market with a slightly more aggressive Grid strategy but with the usual hedging strategies in a minute timeframe.
                                        </p>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <sup>$</sup>1,300<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">You're saving $1,200
                                                quarterly!</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <li>100 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>20 min strategy interval checks</li>
                                            <li>Scan markets with the power of 15 bots</li>
                                            <li>5 event based triggers</li>
                                            <li>Backtesting</li>
                                            <li>Paper (simulated) trading</li>
                                            <li>Trading signals</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges </li>
                                        </ul>
                                        <a href="user/trade?package=monthly-ninja"
                                            class="uk-button uk-button-primary uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Subzero 5.2</h3>
                                        <p class="pricing-des">
                                            Are automated Bot that helps you buy and sell cryptocurrencies at the correct time. The main goal of this Bot is to increase revenue.
                                        </p>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <sup>$</sup>2,800<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">You're saving $2,400 quarterly!</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>500 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all available exchanges</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->

                                            <li>500 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>10 min strategy interval checks</li>
                                            <li>Scan markets with the power of 50 bots</li>
                                            <li>7 event based triggers</li>
                                            <li>Backtesting</li>
                                            <li>Paper (simulated) trading</li>
                                            <li>Trading signals</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges</li>
                                        </ul>
                                        <a href="user/trade?package=monthly-subzero"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Rocket 7.1</h3>
                                        <p class="pricing-des">
                                            Is an AI-driven bot that makes crypto trading accessible, fun, and worthwhile for everyone.
                                        </p>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <sup>$</sup>6,250<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">You're saving $3,150 quarterly!</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>1,000 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all coins for signals</li>-->
                                            <!--<li>market arbitrage</li>-->
                                            <!--<li>algorithm intelligence</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->
                                            <li>1,000 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>5 minute strategy interval checks</li>
                                            <li>Scan markets with the power of 75 bots</li>
                                            <li>15 event based triggers</li>
                                            <li>A.I. strategies and A.I designer</li>
                                            <li>manual trading</li>
                                            <li>all coins for trading signals</li>
                                            <li>market making & arbitrage</li>
                                            <li>Extra Technical Indicators</li>
                                            <li>algorithm intelligence</li>
                                        </ul>
                                        <a href="user/trade?package=monthly-rocket"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- section content end -->
        </div>
        <!-- end monthly -->
        <!-- annualy -->
        <div class="tab-content" id="tab-content-3" style="display:none;">
            <!-- section content begin -->
            <div class="uk-section in-equity-17" style="padding-top:50px !important">
                <div class="uk-container uk-margin-top uk-margin-medium-bottom" style="max-width:1300px">
                    <div class="uk-grid uk-flex uk-flex-center">
                        <div style="width: 100%;">
                            <div class="row uk-grid-collapse uk-child-width-1-4@m in-equity-pricing" data-uk-grid>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Explorer</h3>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">Demo
                                        </h2>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <li>20 positions</li>
                                            <li>portfolio management</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges</li>
                                        </ul>
                                        <a href="user/trade-demo"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-large">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Ninja 3.6</h3>
                                        <p class="pricing-des">
                                            Works in the Gold market with a slightly more aggressive Grid strategy but with the usual hedging strategies in a minute timeframe.
                                        </p>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <sup>$</sup>900<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">You're saving $9,600 annually!</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>100 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all available exchanges</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->
                                            <li>100 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>20 min strategy interval checks</li>
                                            <li>Scan markets with the power of 15 bots</li>
                                            <li>5 event based triggers</li>
                                            <li>Backtesting</li>
                                            <li>Paper (simulated) trading</li>
                                            <li>Trading signals</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges </li>
                                        </ul>
                                        <a href="user/trade?package=annually-ninja"
                                            class="uk-button uk-button-primary uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Subzero 5.2</h3>
                                        <p class="pricing-des">
                                            Are automated Bot that helps you buy and sell cryptocurrencies at the correct time. The main goal of this Bot is to increase revenue.
                                        </p>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <sup>$</sup>2,000<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">You're saving $19,200 annually!</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>500 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all available exchanges</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->
                                            <li>500 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>10 min strategy interval checks</li>
                                            <li>Scan markets with the power of 50 bots</li>
                                            <li>7 event based triggers</li>
                                            <li>Backtesting</li>
                                            <li>Paper (simulated) trading</li>
                                            <li>Trading signals</li>
                                            <li>manual trading</li>
                                            <li>all available exchanges</li>
                                        </ul>
                                        <a href="user/trade?package=annually-subzero"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                                <div>
                                    <div class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
                                        <h3 class="uk-text-large uk-text-muted uk-text-center">Rocket 7.1</h3>
                                        <p class="pricing-des">
                                            Is an AI-driven bot that makes crypto trading accessible, fun, and worthwhile for everyone.
                                        </p>
                                        <h2 class="uk-margin-remove-top uk-margin-remove-bottom uk-text-center">
                                            <sup>$</sup>5,200<sub>/mo</sub>
                                        </h2>
                                        <p class="uk-text-small uk-text-muted uk-text-center">
                                            <span
                                                class="uk-label uk-margin-small-left in-label-small">You're saving $25,200 annually!</span>
                                        </p>
                                        <hr>
                                        <ul class="uk-list uk-list-bullet in-list-check">
                                            <!--<li>1,000 positions</li>-->
                                            <!--<li>portfolio management</li>-->
                                            <!--<li>manual trading</li>-->
                                            <!--<li>all coins for signals</li>-->
                                            <!--<li>market arbitrage</li>-->
                                            <!--<li>algorithm intelligence</li>-->
                                            <!--<li>9.37% withdrawal fee</li>-->
                                            <li>1,000 open positions / exchange</li>
                                            <li>portfolio management</li>
                                            <li>5 minute strategy interval checks</li>
                                            <li>Scan markets with the power of 75 bots</li>
                                            <li>15 event based triggers</li>
                                            <li>A.I. strategies and A.I designer</li>
                                            <li>manual trading</li>
                                            <li>all coins for trading signals</li>
                                            <li>market making & arbitrage</li>
                                            <li>Extra Technical Indicators</li>
                                            <li>algorithm intelligence </li>
                                        </ul>
                                        <a href="user/trade?package=annually-rocket"
                                            class="uk-button uk-button-default uk-border-rounded uk-align-center">Get
                                            Started<i class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- section content end -->
        </div>
        <!-- end annualy -->




        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-src="img/in-equity-2-bg.png"
            data-uk-img style="padding-top: 20px !important;padding-bottom: 40px !important;">
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <h1 class="uk-margin-top">All the features you
                            need.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">
                            Select plans to compare.
                        </p>
                    </div>
                    <div class="uk-width-2-5@m uk-margin-medium-top" style="display: inline-flex;">
                        <select class="form-control cus-select" id="select1">
                            <option value="select" selected="true">Select</option>
                            <option id="sl1-op1" value="op1">Demo</option>
                            <option id="sl1-op2" value="op2">Ninja 3.6</option>
                            <option id="sl1-op3" value="op3">SubZero 5.2</option>
                            <option id="sl1-op4" value="op4">Rocket 7.1</option>
                        </select>
                        <span class="uk-text-lead" style="margin-left: 10px; margin-right: 10px;"> to </span>
                        <select class="form-control cus-select" id="select2">
                            <option value="select" selected="true">Select</option>
                            <option id="sl2-op1" value="op1">Demo</option>
                            <option id="sl2-op2" value="op2">Ninja 3.6</option>
                            <option id="sl2-op3" value="op3">SubZero 5.2</option>
                            <option id="sl2-op4" value="op4">Rocket 7.1</option>
                        </select>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center"
            style="padding-top:0px !important;padding-bottom: 50px !important;" data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-4-5@m uk-text-left">
                        <div class="table-responsive">
                            <table class="table table-centered table-nowrap mb-0">
                                <thead class="thead-light">
                                    <tr>
                                        <th>Features</th>
                                        <th id="header-1">Demo</th>
                                        <th id="header-2">Ninja 3.6</th>
                                        <th id="header-3">SubZero 5.2</th>
                                        <th id="header-4">Rocket 7.1</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <tr>
                                        <td>
                                            Available on
                                            all exchanges
                                        </td>
                                        <td class="content-1">
                                            All exchanges
                                        </td>
                                        <td class="content-2">
                                            All exchanges
                                        </td>
                                        <td class="content-3">
                                            All exchanges
                                        </td>
                                        <td class="content-4">
                                            All exchanges
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Live trading
                                            terminal
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Portfolio
                                            Management
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Manual
                                            trading
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Syncing
                                            positions
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Reserve
                                            positions
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Personal stats
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Global stats
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Strategy
                                            builder
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Strategy
                                            backtesting
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            130+
                                            Indicators &
                                            Candle sticks
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Open
                                            positions
                                        </td>
                                        <td class="content-1">
                                            20
                                        </td>
                                        <td class="content-2">
                                            100
                                        </td>
                                        <td class="content-3">
                                            500
                                        </td>
                                        <td class="content-4">
                                            1000
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Selected
                                            Coins to Scan
                                        </td>
                                        <td class="content-1">
                                            0
                                        </td>
                                        <td class="content-2">
                                            25
                                        </td>
                                        <td class="content-3">
                                            75
                                        </td>
                                        <td class="content-4">
                                            115
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Simultaneous
                                            targets to buy
                                        </td>
                                        <td class="content-1">
                                            0
                                        </td>
                                        <td class="content-2">
                                            20
                                        </td>
                                        <td class="content-3">
                                            45
                                        </td>
                                        <td class="content-4">
                                            70
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Triggers
                                        </td>
                                        <td class="content-1">
                                            0
                                        </td>
                                        <td class="content-2">
                                            5
                                        </td>
                                        <td class="content-3">
                                            15
                                        </td>
                                        <td class="content-4">
                                            25
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            TA Scan
                                            interval
                                        </td>
                                        <td class="content-1">
                                            N/A
                                        </td>
                                        <td class="content-2">
                                            10 minutes
                                        </td>
                                        <td class="content-3">
                                            5 minutes
                                        </td>
                                        <td class="content-4">
                                            2 minutes
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Active bots
                                            per
                                            subscription
                                        </td>
                                        <td class="content-1">
                                            N/A
                                        </td>
                                        <td class="content-2">
                                            1
                                        </td>
                                        <td class="content-3">
                                            1
                                        </td>
                                        <td class="content-4">
                                            1
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Active
                                            simulators per
                                            subscription
                                        </td>
                                        <td class="content-1">
                                            N/A
                                        </td>
                                        <td class="content-2">
                                            1
                                        </td>
                                        <td class="content-3">
                                            1
                                        </td>
                                        <td class="content-4">
                                            1
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Automatic
                                            Trading
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Copy Trading
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Backtesting
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Trailing Features
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Stop-Loss
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Auto-Close
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Take Profit
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Shorting
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            DCA
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Exchange
                                            Arbitrage
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Triangular
                                            Arbitrage
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Allow all Coins
                                            for Signals
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Premium
                                            strategy
                                            indicators
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Algorithm Intelligence
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Market
                                            Making
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-unchecked">
                                                <i class="fas fa-times"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            Support
                                        </td>
                                        <td class="content-1">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-2">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-3">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                        <td class="content-4">
                                            <p class="pricing-checked">
                                                <i class="fas fa-check"></i>
                                            </p>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section" style="background-color: #f7f7f7;">
            <div class="uk-container">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-1-2@m uk-text-center">
                        <p class="uk-text-lead uk-text-muted uk-margin-remove-bottom uk-text-center">
                            Have any question?
                        </p>
                        <h2 class="uk-margin-small-top uk-text-center"><span class="in-highlight">Frequently</span>
                            asked
                            questions</h2>
                    </div>
                    <div class="uk-width-1-1@m">
                        <div class="uk-grid uk-child-width-1-2@m uk-margin-medium-top" data-uk-grid>
                            <div>
                                <ul class="in-faq-2" data-uk-accordion>
                                    <li>
                                        <a class="uk-accordion-title" href="#">
                                            <div class="uk-card uk-card-default uk-card-body uk-border-rounded">
                                                Can I have multiple Rockets per account?
                                            </div>
                                        </a>
                                        <div
                                            class="uk-accordion-content uk-card uk-card-default uk-card-body uk-border-rounded">
                                            <p>
                                                You can have multiple Rockets on a single account. But
                                                remember, a single subscription gives you a single
                                                Rocket AND a single papertrading Rocket
                                            </p>
                                        </div>
                                    </li>
                                    <li>
                                        <a class="uk-accordion-title" href="#">
                                            <div
                                                class="uk-card uk-card-default uk-card-body uk-border-rounded uk-clearfix">
                                                Which payment methods do you accept?
                                            </div>
                                        </a>
                                        <div
                                            class="uk-accordion-content uk-card uk-card-default uk-card-body uk-border-rounded">
                                            <p>
                                                We accept:
                                            </p>
                                            <ul>
                                                <li>Crypto</li>
                                            </ul>
                                        </div>
                                    </li>
                                    <li>
                                        <a class="uk-accordion-title" href="#">
                                            <div class="uk-card uk-card-default uk-card-body uk-border-rounded">
                                                Are my funds safe?
                                            </div>
                                        </a>
                                        <div
                                            class="uk-accordion-content uk-card uk-card-default uk-card-body uk-border-rounded">
                                            <p>
                                                Yes, your funds will always remain on the exchange.
                                                CryptoRocket connects with your exchange by using
                                                API Keys.
                                            </p>
                                        </div>
                                    </li>
                                </ul>
                            </div>
                            <div>
                                <ul class="in-faq-2" data-uk-accordion>
                                    <li>
                                        <a class="uk-accordion-title" href="#">
                                            <div class="uk-card uk-card-default uk-card-body uk-border-rounded">
                                                How long does it take before my support
                                                ticket is resolved?
                                            </div>
                                        </a>
                                        <div
                                            class="uk-accordion-content uk-card uk-card-default uk-card-body uk-border-rounded">
                                            <p>
                                                Rocketta strives for a 24h response time on a
                                                ticket. For very difficult cases and in weekends this
                                                might be a bit longer. Do note that sending multiple
                                                tickets on the same query isn't helping your initial case
                                                and only serves to increase workload on the agents.
                                            </p>
                                        </div>
                                    </li>
                                    <li>
                                        <a class="uk-accordion-title" href="#">
                                            <div class="uk-card uk-card-default uk-card-body uk-border-rounded">
                                                What is the minimum funds I need to start
                                                trading?
                                            </div>
                                        </a>
                                        <div
                                            class="uk-accordion-content uk-card uk-card-default uk-card-body uk-border-rounded">
                                            <p>
                                                The minimum amount of funds you need is $1,700.
                                            </p>
                                        </div>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <input id="trading_type" type="hidden" value="<?php echo ($trading_type); ?>" />


    </main>
    <?php require_once("footer.php"); ?>
    <script type="text/javascript">
        var tabs = $('.tabs');
        var selector = $('.tabs').find('a').length;
        //var selector = $(".tabs").find(".selector");
        var activeItem = tabs.find('.active');
        var activeWidth = activeItem.innerWidth();
        $(".selector").css({
            "left": activeItem.position.left + "px",
            "width": activeWidth + "px"
        });

        $(".tabs").on("click", "a", function(e) {
            e.preventDefault();
            $('.tabs a').removeClass("active");
            $(this).addClass('active');
            var activeWidth = $(this).innerWidth();
            var itemPos = $(this).position();
            $(".selector").css({
                "left": itemPos.left + "px",
                "width": activeWidth + "px"
            });
            $('.tab-content').hide();
            var activeTab = "#tab-content-" + $(this).index();
            $(activeTab).show();
        });

        if ($("#trading_type").val() == "annual") {
            $('.tabs a').removeClass("active");
            $("#annual-tab").addClass('active');
            var activeWidth = $("#annual-tab").innerWidth();
            var itemPos = $("#annual-tab").position();
            $(".selector").css({
                "left": itemPos.left + "px",
                "width": activeWidth + "px"
            });
            $('.tab-content').hide();
            var activeTab = "#tab-content-" + $("#annual-tab").index();
            $(activeTab).show();
        }

        $("#select1").on("change", function() {
            var select1 = this.value;
            var select2 = $("#select2 option:selected").val();

            if (select1 == "select") {
                $("#sl2-op1").show();
                $("#sl2-op2").show();
                $("#sl2-op3").show();
                $("#sl2-op4").show();
                $('#header-1').show();
                $('#header-2').show();
                $('#header-3').show();
                $('#header-4').show();
                $('.content-1').show();
                $('.content-2').show();
                $('.content-3').show();
                $('.content-4').show();
            } else {
                if (select2 != "select") {
                    $('#header-1').hide();
                    $('#header-2').hide();
                    $('#header-3').hide();
                    $('#header-4').hide();
                    $('.content-1').hide();
                    $('.content-2').hide();
                    $('.content-3').hide();
                    $('.content-4').hide();

                    switch (select1) {
                        case "op1":
                            $('#header-1').show();
                            $('.content-1').show();
                            break;
                        case "op2":
                            $('#header-2').show();
                            $('.content-2').show();
                            break;
                        case "op3":
                            $('#header-3').show();
                            $('.content-3').show();
                            break;
                        case "op4":
                            $('#header-4').show();
                            $('.content-4').show();
                            break;
                        default:
                            break;
                    }

                    switch (select2) {
                        case "op1":
                            $('#header-1').show();
                            $('.content-1').show();
                            break;
                        case "op2":
                            $('#header-2').show();
                            $('.content-2').show();
                            break;
                        case "op3":
                            $('#header-3').show();
                            $('.content-3').show();
                            break;
                        case "op4":
                            $('#header-4').show();
                            $('.content-4').show();
                            break;
                        default:
                            break;
                    }
                } else {
                    var hideElement = "#sl2-" + select1;
                    $(hideElement).hide();
                }
            }

        });

        $("#select2").on("change", function() {
            var select2 = this.value;
            var select1 = $("#select1 option:selected").val();

            if (select2 == "select") {
                $("#sl1-op1").show();
                $("#sl1-op2").show();
                $("#sl1-op3").show();
                $("#sl1-op4").show();
                $('#header-1').show();
                $('#header-2').show();
                $('#header-3').show();
                $('#header-4').show();
                $('.content-1').show();
                $('.content-2').show();
                $('.content-3').show();
                $('.content-4').show();
            } else {
                if (select1 != "select") {
                    //execute comparison
                    $('#header-1').hide();
                    $('#header-2').hide();
                    $('#header-3').hide();
                    $('#header-4').hide();
                    $('.content-1').hide();
                    $('.content-2').hide();
                    $('.content-3').hide();
                    $('.content-4').hide();

                    switch (select1) {
                        case "op1":
                            $('#header-1').show();
                            $('.content-1').show();
                            break;
                        case "op2":
                            $('#header-2').show();
                            $('.content-2').show();
                            break;
                        case "op3":
                            $('#header-3').show();
                            $('.content-3').show();
                            break;
                        case "op4":
                            $('#header-4').show();
                            $('.content-4').show();
                            break;
                        default:
                            break;
                    }

                    switch (select2) {
                        case "op1":
                            $('#header-1').show();
                            $('.content-1').show();
                            break;
                        case "op2":
                            $('#header-2').show();
                            $('.content-2').show();
                            break;
                        case "op3":
                            $('#header-3').show();
                            $('.content-3').show();
                            break;
                        case "op4":
                            $('#header-4').show();
                            $('.content-4').show();
                            break;
                        default:
                            break;
                    }
                } else {
                    var hideElement = "#sl1-" + select2;
                    $(hideElement).hide();
                }
            }
        });
    </script>
</body>

</html>