<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>DCA</title>
    <meta name="description" content="Use DCA to invest gradually over time to mitigate risk, or to make up for a loss
making position. Buying extra on a loss making position will lower the average
buying price.">
    <meta name="keywords" content="dollar, cost, averaging, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Dollar Cost Averaging</span>
                        <h1 class="uk-margin-remove"><span class="in-highlight">Don’t worry</span> about
                            buying at the wrong
                            moment.
                        </h1>
                        <p class="uk-text-lead uk-text-muted">Use DCA to invest gradually over time to mitigate risk, or
                            to make up for a loss
                            making position. Buying extra on a loss making position will lower the average
                            buying price.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="../create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/gifs/ft-4.gif" loop=infinite />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/dca-risk.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Beginner</h6>
                                <p class="provider">Mitigate risk
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/ait-adapt.png" alt="award-2"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Pros</h6>
                                <p class="provider">Combat volatility</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/dca-cloud.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Easy</h6>
                                <p class="provider">In the cloud</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-right uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/dca-invest.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning">Invest over time</span>
                        <h1 class="uk-margin-small-bottom">Invest with less risk, <span class="in-highlight">the easy
                                way</span>.</h1>
                        <p class="uk-margin-top uk-text-lead grey">By investing over time, you will average your buying
                            price and will notice less from
                            market movements, as long as the price will go up over time. This makes DCA very
                            suitable for risk averse beginner traders.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-2 uk-background-contain uk-background-center" data-src="img/in-equity-2-bg.png"
            data-uk-img>
            <div class="uk-container uk-margin-top">
                <div class="uk-grid uk-flex uk-flex-center">
                    <div class="uk-width-2xlarge@m uk-text-center">
                        <span class="uk-label uk-label-warning">Easily applied</span>
                        <h1 class="uk-margin-top">Directly at your fingertips.</h1>
                        <p class="uk-text-lead uk-margin-medium-top">Automatically use DCA on loss making positions, or
                            simply select a
                            position and apply a DCA order to it. Your Rocket will do the rest.</p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>