<?php

//For sending outgoing emails(e.g. verification emails)
$smtp_email = "no-reply@rocketta.io";
$smtp_host = "premium241.web-hosting.com";
$smtp_encryption = "tls";
$smtp_username = "no-reply@rocketta.io";
$smtp_password = "9B7BRf2VR@ze";
$smtp_port = 587;

/*$smtp_email = "noreply@rocketta.io";
$smtp_host = "premium241.web-hosting.com";
$smtp_encryption = "tls";
$smtp_username = "noreply@rocketta.io";
$smtp_password = "9B7BRf2VR@ze";
$smtp_port = 587;*/


//For receiving contact us emails
$support_smtp_email = "support@rocketta.io";
$support_smtp_host = "premium241.web-hosting.com";
$support_smtp_encryption = "tls";
$support_smtp_username = "support@rocketta.io";
$support_smtp_password = "&fhU6k{~s&)A";
$support_smtp_port = 465;