<!DOCTYPE html>
<html lang="zxx" dir="ltr">

<head>
    <!-- Standard Meta -->
    <meta charset="utf-8">
    <title>Individuals</title>
    <meta name="description" content="Wish you could trade like a pro? Now you can. Become a pro
                            with Rocketta and use our advanced tools to improve your skills. Your private trading
                            companion is active 24/7, and trades like a pro trader.">
    <meta name="keywords" content="individuals, psps, automatic, trading, Cryptotrading, trade">
    <?php require("../includes/header.php"); ?>
    <main>
        <!-- section content begin -->
        <div class="uk-section in-equity-16">
            <div class="uk-container uk-margin-top uk-margin-large-bottom">
                <div class="uk-grid uk-grid-large uk-flex uk-flex-middle" data-uk-grid>
                    <div class="uk-width-3-5@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Individuals</span>
                        <h1 class="uk-margin-remove"><span class="in-highlight">Jumpstart</span> your trading.
                        </h1>
                        <p class="uk-text-lead uk-text-muted">Wish you could trade like a pro? Now you can. Become a pro
                            with Rocketta and use our advanced tools to improve your skills. Your private trading
                            companion is active 24/7, and trades like a pro trader.</p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/create-account">Let's get started<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2-5@m">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/login-bg.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <div class="uk-section in-equity-5" style="padding-top: 20px;">
            <div class="uk-container uk-margin-remove-bottom">
                <div class="uk-grid uk-child-width-1-3@m uk-child-width-1-2@s" data-uk-grid>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/aut-copy.png" alt="award-1"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Copy</h6>
                                <p class="provider">A pro trader
                                </p>
                            </div>
                        </div>
                    </div>
                    <div>
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/aut-247.png" alt="award-2"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Active</h6>
                                <p class="provider">24/7</p>
                            </div>
                        </div>
                    </div>
                    <div class="">
                        <div class="uk-flex uk-flex-left in-award">
                            <div class="uk-margin-small-right">
                                <img src="../img/in-lazy.gif" data-src="../img/icons/prt-exchanges.png" alt="award-3"
                                    style="width: 60px;" data-uk-img>
                            </div>
                            <div>
                                <h6>Jumpstart</h6>
                                <p class="provider">Your trading</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/prt-exchanges.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Social trading</span>
                        <h1 class="uk-margin-small-bottom">
                            Trade <span class="in-highlight">like a pro</span>.Skip the learning curve.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Become a pro by using bots on our marketplace.
                            Download strategies from
                            professionals and scan the markets, or download pre-configured bot templates. Or
                            simply follow trading signals, which tell your bot exactly when to buy or sell.
                        </p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/login">Take a tour<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Automatic trading</span>
                        <h1 class="uk-margin-small-bottom">
                            Watch the markets. <span class="in-highlight">Simultaneously. 24/7.</span>
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Crypto trading is 24/7. So is your Rocketta.
                            Your Rocket scans up to 75
                            markets, simultaneously. It does the work, so you don’t have to.
                        </p>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-convert.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/social-trading.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Experiments</span>
                        <h1 class="uk-margin-small-bottom">
                            Get experienced. <span class="in-highlight">Without risks.</span>
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Try, without risks. Simulate your trading, and test
                            your Rockets. With every
                            subscription you buy, you can build one “real” Rocket and one simulator. While
                            your real Rocket runs, you can test new strategies on your simulator.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #fff;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Trailing & DCA</span>
                        <h1 class="uk-margin-small-bottom">
                            The <span class="in-highlight">magic touch</span>, only a bot can do.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">Selling too early? Use the trailing stop-loss, which
                            tracks the price up and only
                            sells when it drops. Buying at the wrong moments? Use DCA to buy extra and
                            lower your average buying price. All automatically.
                        </p>
                        <a class="uk-button uk-button-primary uk-border-rounded uk-margin-small-top"
                            href="https://rocketta.io/login">Take a tour<i
                                class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                    </div>
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/ttm-offer.jpg" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <!-- section content begin -->
        <div class="uk-section in-equity-3 in-offset-top-20" style="background-color: #f7f7f7;">
            <div class="uk-container uk-margin-large-bottom">
                <div class="uk-grid uk-flex uk-flex-middle">
                    <div class="uk-width-2xlarge uk-flex uk-flex-left uk-flex-center@s">
                        <div
                            class="uk-card uk-card-body uk-card-default uk-border-rounded in-margin-top-60@s in-margin-bottom-40@s">
                            <img src="../img/sol-mnp-support.jpg" />
                        </div>
                    </div>
                    <div class="uk-width-expand@m">
                        <span class="uk-label uk-label-warning in-margin-bottom20@s">Personal support</span>
                        <h1 class="uk-margin-small-bottom">
                            We've got <span class="in-highlight">your back</span>.
                        </h1>
                        <p class="uk-margin-top uk-text-lead grey">We understand that starting with grandhopperbot can
                            be a lot to take in. That’s
                            why our kind and knowledgeable support agents are ready to help you 24/7. See
                            them as your private trading mentors, here to answer all your questions whenever
                            you don’t understand something.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <!-- section content end -->
        <?php require_once("../includes/create-account.php"); ?>
    </main>
    <?php require_once("../includes/footer.php"); ?>
    </body>

</html>