<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="theme-color" content="#FCB42D" />
<!-- Site Properties -->
<!-- critical preload -->
<link rel="preload" href="js/vendors/uikit.min.js" as="script">
<link rel="preload" href="css/vendors/uikit.min.css" as="style">
<link rel="preload" href="css/style.css" as="style">
<!-- icon preload -->
<link rel="preload" href="fonts/fa-brands-400.woff2" as="font" type="font/woff2" crossorigin>
<link rel="preload" href="fonts/fa-solid-900.woff2" as="font" type="font/woff2" crossorigin>
<!-- font preload -->
<link rel="preload" href="fonts/archivo-v9-latin-regular.woff2" as="font" type="font/woff2" crossorigin>
<link rel="preload" href="fonts/archivo-v9-latin-300.woff2" as="font" type="font/woff2" crossorigin>
<link rel="preload" href="fonts/archivo-v9-latin-700.woff2" as="font" type="font/woff2" crossorigin>
<!-- Favicon and apple icon -->
<link rel="shortcut icon" href="img/favicon.png" type="image/x-icon">
<link rel="apple-touch-icon-precomposed" href="apple-touch-icon.png">
<!-- css -->
<link rel="stylesheet" href="css/vendors/uikit.min.css">
<link rel="stylesheet" href="css/style.css">
<link rel="stylesheet" href="css/ta_custom_style.css">

<script type="text/javascript">
function googleTranslateElementInit() {
    new google.translate.TranslateElement({
        pageLanguage: 'en',
        layout: google.translate.TranslateElement.InlineLayout.SIMPLE
    }, 'google_translate_element');
}
</script>
<script type="text/javascript" src="//translate.google.com/translate_a/element.js?cb=googleTranslateElementInit">
</script>
<script type="text/javascript" src="//translate.google.com/#en/hi/Hello"></script>
<style>
.goog-te-banner-frame.skiptranslate {
    display: none !important;
}

body {
    top: 0px !important;
}

@media print {
    #google_translate_element {
        display: none;
    }
}

.goog-te-menu-value {
    color: #000 !important;
    font-size: 14px !important;
    padding-top: 15px !important;
    padding-bottom: 10px !important;
    padding-left: 5px;
}
.goog-te-gadget-icon {
    display: none;
}
</style>
<!-- Chatra {literal} -->
<script>
    (function(d, w, c) {
        w.ChatraID = '2etogsPTNBWSecDqX';
        var s = d.createElement('script');
        w[c] = w[c] || function() {
            (w[c].q = w[c].q || []).push(arguments);
        };
        s.async = true;
        s.src = 'https://call.chatra.io/chatra.js';
        if (d.head) d.head.appendChild(s);
    })(document, window, 'Chatra');
</script>
<!-- /Chatra {/literal} -->
</head>

<body>
    <!-- preloader begin -->
    <div class="in-loader">
        <div></div>
        <div></div>
        <div></div>
    </div>
    <!-- preloader end -->
    <header>
        <!-- header content begin -->
        <div class="uk-section uk-padding-remove-vertical">
            <nav class="uk-navbar-container uk-navbar-transparent"
                data-uk-sticky="show-on-up: true; animation: uk-animation-slide-top;">
                <div class="uk-container" data-uk-navbar>
                    <div class="uk-navbar-left">
                        <div class="uk-navbar-item">
                            <!-- logo begin -->
                            <a class="uk-logo" href="index.php" style="color:#ffffff">
                                <img src="img/in-lazy.gif" data-src="img/logo-white.png" alt="logo" width="190"
                                    height="46" data-uk-img>
                            </a>
                            <!-- logo end -->
                            <!-- navigation begin -->
                            <ul class="uk-navbar-nav uk-visible@m">
                                <li><a href="#">Why Rocketta<i class="fas fa-chevron-down"></i></a>
                                    <div class="uk-navbar-dropdown">
                                        <ul class="uk-nav uk-navbar-dropdown-nav">
                                            <li><a href="features/automatic-trading"><span><img class="nav-ico"
                                                            src="img/icons/auto-trading.png" /> </span><span
                                                        class="d-block">Automatic
                                                        Trading<br /><span class="uk-navbar-subtitle">Bots outperform
                                                            humans.</span></span></a>
                                            </li>
                                            <li><a href="features/algorithm-intelligence"><span><img class="nav-ico"
                                                            src="img/icons/ai-trading.png" /> </span><span
                                                        class="d-block">AI
                                                        Trading<br /><span class="uk-navbar-subtitle">Let your bot learn
                                                            and decide for itself.</span></span></a></li>
                                            <li><a href="features/trading-terminal"><span><img class="nav-ico"
                                                            src="img/icons/trading-terminal.png" /> </span><span
                                                        class="d-block">Trading
                                                        Terminal<br /><span class="uk-navbar-subtitle">Manage your
                                                            complete portfolio.From one place.</span></span></a></li>
                                            <li><a href="features/dca"><span><img class="nav-ico"
                                                            src="img/icons/dca.png" /> </span><span
                                                        class="d-block">DCA<br /><span class="uk-navbar-subtitle">Don't
                                                            worry buying at the right
                                                            moment.</span></span></a></li>
                                            <li><a href="features/pro-tools"><span><img class="nav-ico"
                                                            src="img/icons/pro-tools.png" /> </span><span
                                                        class="d-block">Pro tools<br /><span
                                                            class="uk-navbar-subtitle">Leverage market inefficiency or
                                                            liquidity.</span></span></a></li>
                                        </ul>
                                    </div>
                                </li>
                                <li><a href="#">Solutions<i class="fas fa-chevron-down"></i></a>
                                    <div class="uk-navbar-dropdown">
                                        <ul class="uk-nav uk-navbar-dropdown-nav">
                                            <li><a href="solutions/miners-and-psps"><span><img class="nav-ico"
                                                            src="img/icons/miners-and-psps.png" /> </span><span
                                                        class="d-block">Miners & PSPs<br /><span
                                                            class="uk-navbar-subtitle">Automatically convert
                                                            funds.</span></span></a></li>
                                            <li><a href="solutions/individuals"><span><img class="nav-ico"
                                                            src="img/icons/individuals.png" /> </span><span
                                                        class="d-block">Individuals<br /><span
                                                            class="uk-navbar-subtitle">Jumpstart your
                                                            trading.</span></span></a></li>
                                            <li><a href="solutions/advanced-traders"><span><img class="nav-ico"
                                                            src="img/icons/advanced-traders.png" /> </span><span
                                                        class="d-block">Advanced traders<br /><span
                                                            class="uk-navbar-subtitle">Stay ahead of the
                                                            curve.</span></span></a></li>
                                        </ul>
                                    </div>
                                </li>
                                <li><a href="pricing">Trading Bots</a></li>
                                <li><a href="#">Company<i class="fas fa-chevron-down"></i></a>
                                    <div class="uk-navbar-dropdown">
                                        <ul class="uk-nav uk-navbar-dropdown-nav">
                                            <li><a href="company/about"><span><img class="nav-ico"
                                                            src="img/icons/about-us.png" /> </span><span
                                                        class="d-block">About Us<br /><span
                                                            class="uk-navbar-subtitle"></span></span></a></li>
                                            <li><a href="contact-us"><span><img class="nav-ico"
                                                            src="img/icons/about-us.png" /> </span><span
                                                        class="d-block">Contact Us<br /><span
                                                            class="uk-navbar-subtitle"></span></span></a></li>
                                        </ul>
                                    </div>
                                </li>
                            </ul>
                            <!-- navigation end -->
                        </div>
                    </div>
                    <div class="uk-navbar-right">
                        <div class="uk-navbar-item uk-visible@m in-optional-nav">
                            <a href="login" class="uk-button uk-button-text">Log in<i
                                    class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                            <a href="create-account" style="margin-right: 20px;"
                                class="uk-button uk-button-primary uk-border-rounded">Sign up<i
                                    class="fas fa-arrow-circle-right uk-margin-small-left"></i></a>
                            <div id="google_translate_element"></div>
                        </div>
                    </div>
                </div>
            </nav>
        </div> 
        
        <!-- header content end -->
    </header>