  <!-- Favicon -->
  <link rel="shortcut icon" type="image/x-icon" href="../img/favicon.png">
  <!-- vendor css -->
  <link href="../lib/@fortawesome/fontawesome-free/css/all.min.css" rel="stylesheet">
  <link href="../lib/ionicons/css/ionicons.min.css" rel="stylesheet">
  <link href="../lib/jqvmap/jqvmap.min.css" rel="stylesheet">
  <link rel="stylesheet" href="../assets/vendors/bootstrap-datepicker/bootstrap-datepicker.min.css">


  <!-- DashForge CSS -->
  <link rel="stylesheet" href="../assets/css/dashforge.css">
  <link rel="stylesheet" href="../assets/css/dashforge.dashboard.css">
  <link rel="stylesheet" href="../assets/css/skin.charcoal.css">
  <style type="text/css">
tbody tr {
    cursor: pointer;
}

tbody tr:hover {
    background-color: #edf1f5 !important;
}

tbody a {
    color: #0168fa;
}

.search-field {
    padding-top: 28px !important;
}

/* Style the search field */
.search-field input[type=text] {
    float: left;
    width: 80%;
}

.search-icon {
    margin-top: -3px;
}

.search-field button {
    float: left;
    width: 20%;
    background: #0168fa;
    color: white;
    font-size: 10px;
    border-left: none;
    /* Prevent double borders */
    cursor: pointer;
    height: 38px;
    margin-left: -5px;
}

.search-field button:hover {
    background: #0148ae;
    color: white;
}

.search-field::after {
    content: "";
    clear: both;
    display: table;
}

.form-group .form-control {
    padding: 0.625rem 1.1875rem !important;
}

.create-button button {
    float: right;
    width: fit-content;
    background: #0168fa;
    color: white;
    font-size: 14px;
    border-left: none;
    cursor: pointer;
    height: 38px;
    margin-left: -5px;
}
  </style>
  </style>
  </head>

  <body class="page-profile" id="top_area">

      <aside class="aside aside-fixed">
          <div class="aside-header">
              <img src="../img/logo-white.png" class="aside-logo" style="width: 160px;" />
              <a href="" class="aside-menu-link">
                  <i data-feather="menu"></i>
              </a>
          </div>
          <div class="aside-body">
              <ul class="nav nav-aside">
                  <li id="mn-dashboard" class="nav-item"><a href="home" class="nav-link"><i
                              data-feather="pie-chart"></i>
                          <span>Dashboard</span></a></li>
                  <li id="mn-users" class="nav-item"><a href="users" class="nav-link"><i data-feather="users"></i>
                          <span>Users</span></a></li>
                  <li id="mn-users-referrals" class="nav-item"><a href="users-referrals" class="nav-link"><i data-feather="users"></i>
                          <span>Referrals</span></a></li>
                  <li id="mn-invoices" class="nav-item"><a href="invoices" class="nav-link"><i
                              data-feather="layers"></i>
                          <span>Invoices</span></a></li>
                  <li id="mn-transactions" class="nav-item"><a href="transactions" class="nav-link"><i
                              data-feather="briefcase"></i>
                          <span>Transactions</span></a></li>
                  <li id="mn-withdrawals" class="nav-item"><a href="withdrawals" class="nav-link"><i
                              data-feather="dollar-sign"></i>
                          <span>Withdrawals</span></a></li>
                  <li id="mn-trading-balances" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="credit-card"></i> <span>Trading Balances</span></a>
                      <ul>
                          <li id="mn-demo-trading-balances"><a href="demo-trading-balances">Demo</a></li>
                          <li id="mn-monthly-trading-balances"><a href="monthly-trading-balances">Monthly</a></li>
                          <li id="mn-quarterly-trading-balances"><a href="quarterly-trading-balances">Quarterly</a></li>
                          <li id="mn-annually-trading-balances"><a href="annually-trading-balances">Annually</a></li>
                          <li id="mn-bot-trading-balances"><a href="bot-trading-balances">Community Bot</a></li>
                      </ul>
                  </li>
                  <li id="mn-trading-history" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="bar-chart"></i> <span>Trading History</span></a>
                      <ul>
                          <li id="mn-demo-trading-history"><a href="demo-trading-history">Demo</a></li>
                          <li id="mn-monthly-trading-history"><a href="monthly-trading-history">Monthly</a></li>
                          <li id="mn-quarterly-trading-history"><a href="quarterly-trading-history">Quarterly</a></li>
                          <li id="mn-annually-trading-history"><a href="annually-trading-history">Annually</a></li>
                          <li id="mn-bot-trading-history"><a href="bot-trading-history">Community Bot</a></li>
                      </ul>
                  </li>
                  <li id="identity-verification" class="nav-item"><a href="identity-verification" class="nav-link"><i
                              data-feather="dollar-sign"></i>
                          <span>Identity Verification</span></a></li>
                  <li id="mn-create-trade" class="nav-item"><a href="create-trade" class="nav-link"><i
                              data-feather="book"></i>
                          <span>Create Trade</span></a></li>

                  <!-- bonus account -->
                  <li id="mn-bonus-history" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="bar-chart"></i> <span>Bonus Account</span></a>
                      <ul>
                          <li id="mn-bonus-account"><a href="bonus-account">Account</a></li>
                          <li id="mn-bonus-account-balances"><a href="bonus-account-balances">Account Balances</a></li>
                          <li id="mn-bonus-withdrawals"><a href="bonus-withdrawals">Withdrawals</a></li>
                          <li id="mn-bonus-transactions"><a href="bonus-transactions">Transactions</a></li>
                      </ul>
                  </li>
                  
                  <!--<li id="mn-bot-account" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="bar-chart"></i> <span>Community Bot</span></a>
                      <ul>
                          <li id="mn-bot-account"><a href="bot-account">Account</a></li>
                          <li id="mn-bot-account-balances"><a href="bot-account-balances">Account Balances</a></li>
                          <li id="mn-bot-withdrawals"><a href="bot-withdrawals">Withdrawals</a></li>
                          <li id="mn-bot-transactions"><a href="bot-transactions">Transactions</a></li>
                          <li id="mn-bot-invoices"><a href="bot-invoices">Invoices</a></li>
                      </ul>
                  </li>-->

                  <li id="mn-charges" class="nav-item"><a href="charges" class="nav-link"><i
                              data-feather="dollar-sign"></i>
                          <span>User Charges Deposits</span></a></li>

                  <li id="redeem-code" class="nav-item">
                      <a href="redeem-code" class="nav-link">
                          <i data-feather="dollar-sign"></i>
                          <span>Redeem Code</span>
                      </a>
                  </li>

                  <!--<li id="withdraw" class="nav-item">-->
                  <!--    <a href="withdraw" class="nav-link">-->
                  <!--        <i data-feather="dollar-sign"></i>-->
                  <!--        <span>Withdraw</span>-->
                  <!--    </a>-->
                  <!--</li>-->
                  <!--<li id="profit" class="nav-item"><a href="profit" class="nav-link"><i data-feather="dollar-sign"></i>-->
                  <!--        <span>Profit</span></a></li>-->

                  <li id="mn-settings" class="nav-item with-sub">
                      <a href="" class="nav-link"><i data-feather="settings"></i> <span>Settings</span></a>
                      <ul>
                          <li id="mn-app-settings"><a href="app-settings">App</a></li>
                          <li id="mn-change-password"><a href="change-password">Change Password</a></li>
                      </ul>
                  </li>
                  <li class="nav-item"><a href="logout" class="nav-link"><i data-feather="power"></i>
                          <span>Log Out</span></a></li>
              </ul>
          </div>
      </aside>